@@ -1,9 +1,9 @@
 function h = generalizedBiasForces(KinDynModel)
 
-    % GENERALIZEDBIASFORCES retrieves the generalized bias forces from 
-    %                            the reduced model. 
+    % GENERALIZEDBIASFORCES retrieves the generalized bias forces from
+    %                       the reduced model.
     %
-    % This matlab function wraps a functionality of the iDyntree library.                     
+    % This matlab function wraps a functionality of the iDyntree library.
     % For further info see also: https://github.com/robotology/idyntree
     %
     % FORMAT:  h = generalizedBiasForces(KinDynModel)
@@ -14,26 +14,22 @@ function h = generalizedBiasForces(KinDynModel)
     %
     % Author : Gabriele Nava (gabriele.nava@iit.it)
     %
-    % Copyright (C) 2019 Istituto Italiano di Tecnologia (IIT). All rights reserved.
-    % This software may be modified and distributed under the terms of the
-    % GNU Lesser General Public License v2.1 or any later version.
+    % SPDX-FileCopyrightText: Fondazione Istituto Italiano di Tecnologia (IIT)
+    % SPDX-License-Identifier: BSD-3-Clause
 
     %% ------------Initialization----------------
-    
-    % create the vector that must be populated with the bias forces
-    h_iDyntree = iDynTree.FreeFloatingGeneralizedTorques(KinDynModel.kinDynComp.model);
-    
+
     % get the bias forces
-    ack = KinDynModel.kinDynComp.generalizedBiasForces(h_iDyntree);
-    
+    ack = KinDynModel.kinDynComp.generalizedBiasForces(KinDynModel.dynamics.h_iDyntree);
+
     % check for errors
     if ~ack
         error('[generalizedBiasForces]: unable to get the bias forces from the reduced model.')
     end
-    
+
     % convert to Matlab format: compute the base bias acc (h_b) and the
     % joint bias acc (h_s) and concatenate them
-    h_b = h_iDyntree.baseWrench.toMatlab;
-    h_s = h_iDyntree.jointTorques.toMatlab;   
+    h_b = KinDynModel.dynamics.h_iDyntree.baseWrench.toMatlab;
+    h_s = KinDynModel.dynamics.h_iDyntree.jointTorques.toMatlab;
     h   = [h_b;h_s];
 end
