@@ -1,15 +1,15 @@
-classdef BerdyOptions < SwigRef
+classdef BerdyOptions < iDynTreeSwigRef
   methods
     function this = swig_this(self)
       this = iDynTreeMEX(3, self);
     end
     function self = BerdyOptions(varargin)
-      if nargin==1 && strcmp(class(varargin{1}),'SwigRef')
+      if nargin==1 && strcmp(class(varargin{1}),'iDynTreeSwigRef')
         if ~isnull(varargin{1})
           self.swigPtr = varargin{1}.swigPtr;
         end
       else
-        tmp = iDynTreeMEX(1504, varargin{:});
+        tmp = iDynTreeMEX(1645, varargin{:});
         self.swigPtr = tmp.swigPtr;
         tmp.SwigClear();
       end
@@ -18,88 +18,88 @@ classdef BerdyOptions < SwigRef
       narginchk(1, 2)
       if nargin==1
         nargoutchk(0, 1)
-        varargout{1} = iDynTreeMEX(1505, self);
+        varargout{1} = iDynTreeMEX(1646, self);
       else
         nargoutchk(0, 0)
-        iDynTreeMEX(1506, self, varargin{1});
+        iDynTreeMEX(1647, self, varargin{1});
       end
     end
     function varargout = includeAllNetExternalWrenchesAsDynamicVariables(self, varargin)
       narginchk(1, 2)
       if nargin==1
         nargoutchk(0, 1)
-        varargout{1} = iDynTreeMEX(1507, self);
+        varargout{1} = iDynTreeMEX(1648, self);
       else
         nargoutchk(0, 0)
-        iDynTreeMEX(1508, self, varargin{1});
+        iDynTreeMEX(1649, self, varargin{1});
       end
     end
     function varargout = includeAllJointAccelerationsAsSensors(self, varargin)
       narginchk(1, 2)
       if nargin==1
         nargoutchk(0, 1)
-        varargout{1} = iDynTreeMEX(1509, self);
+        varargout{1} = iDynTreeMEX(1650, self);
       else
         nargoutchk(0, 0)
-        iDynTreeMEX(1510, self, varargin{1});
+        iDynTreeMEX(1651, self, varargin{1});
       end
     end
     function varargout = includeAllJointTorquesAsSensors(self, varargin)
       narginchk(1, 2)
       if nargin==1
         nargoutchk(0, 1)
-        varargout{1} = iDynTreeMEX(1511, self);
+        varargout{1} = iDynTreeMEX(1652, self);
       else
         nargoutchk(0, 0)
-        iDynTreeMEX(1512, self, varargin{1});
+        iDynTreeMEX(1653, self, varargin{1});
       end
     end
     function varargout = includeAllNetExternalWrenchesAsSensors(self, varargin)
       narginchk(1, 2)
       if nargin==1
         nargoutchk(0, 1)
-        varargout{1} = iDynTreeMEX(1513, self);
+        varargout{1} = iDynTreeMEX(1654, self);
       else
         nargoutchk(0, 0)
-        iDynTreeMEX(1514, self, varargin{1});
+        iDynTreeMEX(1655, self, varargin{1});
       end
     end
     function varargout = includeFixedBaseExternalWrench(self, varargin)
       narginchk(1, 2)
       if nargin==1
         nargoutchk(0, 1)
-        varargout{1} = iDynTreeMEX(1515, self);
+        varargout{1} = iDynTreeMEX(1656, self);
       else
         nargoutchk(0, 0)
-        iDynTreeMEX(1516, self, varargin{1});
+        iDynTreeMEX(1657, self, varargin{1});
       end
     end
     function varargout = jointOnWhichTheInternalWrenchIsMeasured(self, varargin)
       narginchk(1, 2)
       if nargin==1
         nargoutchk(0, 1)
-        varargout{1} = iDynTreeMEX(1517, self);
+        varargout{1} = iDynTreeMEX(1658, self);
       else
         nargoutchk(0, 0)
-        iDynTreeMEX(1518, self, varargin{1});
+        iDynTreeMEX(1659, self, varargin{1});
       end
     end
     function varargout = baseLink(self, varargin)
       narginchk(1, 2)
       if nargin==1
         nargoutchk(0, 1)
-        varargout{1} = iDynTreeMEX(1519, self);
+        varargout{1} = iDynTreeMEX(1660, self);
       else
         nargoutchk(0, 0)
-        iDynTreeMEX(1520, self, varargin{1});
+        iDynTreeMEX(1661, self, varargin{1});
       end
     end
     function varargout = checkConsistency(self,varargin)
-      [varargout{1:nargout}] = iDynTreeMEX(1521, self, varargin{:});
+      [varargout{1:nargout}] = iDynTreeMEX(1662, self, varargin{:});
     end
     function delete(self)
       if self.swigPtr
-        iDynTreeMEX(1522, self);
+        iDynTreeMEX(1663, self);
         self.SwigClear();
       end
     end
