@@ -1,63 +1,63 @@
-classdef Position < iDynTree.PositionRaw
+classdef Position < iDynTree.Vector3
   methods
     function self = Position(varargin)
-      self@iDynTree.PositionRaw(iDynTreeSwigRef.Null);
+      self@iDynTree.Vector3(iDynTreeSwigRef.Null);
       if nargin==1 && strcmp(class(varargin{1}),'iDynTreeSwigRef')
         if ~isnull(varargin{1})
           self.swigPtr = varargin{1}.swigPtr;
         end
       else
-        tmp = iDynTreeMEX(413, varargin{:});
+        tmp = iDynTreeMEX(479, varargin{:});
         self.swigPtr = tmp.swigPtr;
         tmp.SwigClear();
       end
     end
     function varargout = changePoint(self,varargin)
-      [varargout{1:nargout}] = iDynTreeMEX(414, self, varargin{:});
+      [varargout{1:nargout}] = iDynTreeMEX(480, self, varargin{:});
     end
     function varargout = changeRefPoint(self,varargin)
-      [varargout{1:nargout}] = iDynTreeMEX(415, self, varargin{:});
+      [varargout{1:nargout}] = iDynTreeMEX(481, self, varargin{:});
     end
     function varargout = changeCoordinateFrame(self,varargin)
-      [varargout{1:nargout}] = iDynTreeMEX(416, self, varargin{:});
+      [varargout{1:nargout}] = iDynTreeMEX(482, self, varargin{:});
     end
     function varargout = changePointOf(self,varargin)
-      [varargout{1:nargout}] = iDynTreeMEX(419, self, varargin{:});
+      [varargout{1:nargout}] = iDynTreeMEX(485, self, varargin{:});
     end
     function varargout = plus(self,varargin)
-      [varargout{1:nargout}] = iDynTreeMEX(420, self, varargin{:});
+      [varargout{1:nargout}] = iDynTreeMEX(486, self, varargin{:});
     end
     function varargout = minus(self,varargin)
-      [varargout{1:nargout}] = iDynTreeMEX(421, self, varargin{:});
+      [varargout{1:nargout}] = iDynTreeMEX(487, self, varargin{:});
     end
     function varargout = uminus(self,varargin)
-      [varargout{1:nargout}] = iDynTreeMEX(422, self, varargin{:});
+      [varargout{1:nargout}] = iDynTreeMEX(488, self, varargin{:});
     end
     function varargout = mtimes(self,varargin)
-      [varargout{1:nargout}] = iDynTreeMEX(423, self, varargin{:});
+      [varargout{1:nargout}] = iDynTreeMEX(489, self, varargin{:});
     end
     function varargout = toString(self,varargin)
-      [varargout{1:nargout}] = iDynTreeMEX(424, self, varargin{:});
+      [varargout{1:nargout}] = iDynTreeMEX(490, self, varargin{:});
     end
     function varargout = display(self,varargin)
-      [varargout{1:nargout}] = iDynTreeMEX(425, self, varargin{:});
+      [varargout{1:nargout}] = iDynTreeMEX(491, self, varargin{:});
     end
     function delete(self)
       if self.swigPtr
-        iDynTreeMEX(427, self);
+        iDynTreeMEX(493, self);
         self.SwigClear();
       end
     end
   end
   methods(Static)
     function varargout = compose(varargin)
-     [varargout{1:nargout}] = iDynTreeMEX(417, varargin{:});
+     [varargout{1:nargout}] = iDynTreeMEX(483, varargin{:});
     end
     function varargout = inverse(varargin)
-     [varargout{1:nargout}] = iDynTreeMEX(418, varargin{:});
+     [varargout{1:nargout}] = iDynTreeMEX(484, varargin{:});
     end
     function varargout = Zero(varargin)
-     [varargout{1:nargout}] = iDynTreeMEX(426, varargin{:});
+     [varargout{1:nargout}] = iDynTreeMEX(492, varargin{:});
     end
   end
 end
