@@ -1,70 +1,70 @@
-classdef Vector10 < SwigRef
+classdef Vector10 < iDynTreeSwigRef
   methods
     function this = swig_this(self)
       this = iDynTreeMEX(3, self);
     end
     function self = Vector10(varargin)
-      if nargin==1 && strcmp(class(varargin{1}),'SwigRef')
+      if nargin==1 && strcmp(class(varargin{1}),'iDynTreeSwigRef')
         if ~isnull(varargin{1})
           self.swigPtr = varargin{1}.swigPtr;
         end
       else
-        tmp = iDynTreeMEX(368, varargin{:});
+        tmp = iDynTreeMEX(443, varargin{:});
         self.swigPtr = tmp.swigPtr;
         tmp.SwigClear();
       end
     end
     function varargout = paren(self,varargin)
-      [varargout{1:nargout}] = iDynTreeMEX(369, self, varargin{:});
+      [varargout{1:nargout}] = iDynTreeMEX(444, self, varargin{:});
     end
     function varargout = brace(self,varargin)
-      [varargout{1:nargout}] = iDynTreeMEX(370, self, varargin{:});
+      [varargout{1:nargout}] = iDynTreeMEX(445, self, varargin{:});
     end
     function varargout = getVal(self,varargin)
-      [varargout{1:nargout}] = iDynTreeMEX(371, self, varargin{:});
+      [varargout{1:nargout}] = iDynTreeMEX(446, self, varargin{:});
     end
     function varargout = setVal(self,varargin)
-      [varargout{1:nargout}] = iDynTreeMEX(372, self, varargin{:});
+      [varargout{1:nargout}] = iDynTreeMEX(447, self, varargin{:});
     end
     function varargout = cbegin(self,varargin)
-      [varargout{1:nargout}] = iDynTreeMEX(373, self, varargin{:});
+      [varargout{1:nargout}] = iDynTreeMEX(448, self, varargin{:});
     end
     function varargout = cend(self,varargin)
-      [varargout{1:nargout}] = iDynTreeMEX(374, self, varargin{:});
+      [varargout{1:nargout}] = iDynTreeMEX(449, self, varargin{:});
     end
     function varargout = begin(self,varargin)
-      [varargout{1:nargout}] = iDynTreeMEX(375, self, varargin{:});
+      [varargout{1:nargout}] = iDynTreeMEX(450, self, varargin{:});
     end
     function varargout = end(self,varargin)
-      [varargout{1:nargout}] = iDynTreeMEX(376, self, varargin{:});
+      [varargout{1:nargout}] = iDynTreeMEX(451, self, varargin{:});
     end
     function varargout = size(self,varargin)
-      [varargout{1:nargout}] = iDynTreeMEX(377, self, varargin{:});
+      [varargout{1:nargout}] = iDynTreeMEX(452, self, varargin{:});
     end
     function varargout = data(self,varargin)
-      [varargout{1:nargout}] = iDynTreeMEX(378, self, varargin{:});
+      [varargout{1:nargout}] = iDynTreeMEX(453, self, varargin{:});
     end
     function varargout = zero(self,varargin)
-      [varargout{1:nargout}] = iDynTreeMEX(379, self, varargin{:});
+      [varargout{1:nargout}] = iDynTreeMEX(454, self, varargin{:});
     end
     function varargout = fillBuffer(self,varargin)
-      [varargout{1:nargout}] = iDynTreeMEX(380, self, varargin{:});
+      [varargout{1:nargout}] = iDynTreeMEX(455, self, varargin{:});
     end
     function varargout = toString(self,varargin)
-      [varargout{1:nargout}] = iDynTreeMEX(381, self, varargin{:});
+      [varargout{1:nargout}] = iDynTreeMEX(456, self, varargin{:});
     end
     function varargout = display(self,varargin)
-      [varargout{1:nargout}] = iDynTreeMEX(382, self, varargin{:});
+      [varargout{1:nargout}] = iDynTreeMEX(457, self, varargin{:});
     end
     function varargout = toMatlab(self,varargin)
-      [varargout{1:nargout}] = iDynTreeMEX(383, self, varargin{:});
+      [varargout{1:nargout}] = iDynTreeMEX(458, self, varargin{:});
     end
     function varargout = fromMatlab(self,varargin)
-      [varargout{1:nargout}] = iDynTreeMEX(384, self, varargin{:});
+      [varargout{1:nargout}] = iDynTreeMEX(459, self, varargin{:});
     end
     function delete(self)
       if self.swigPtr
-        iDynTreeMEX(385, self);
+        iDynTreeMEX(460, self);
         self.SwigClear();
       end
     end
