@@ -3,8 +3,11 @@
 #include "error_utilities.h"
 
 #include <string>
-#include <iDynTree/ModelIO/ModelExporter.h>
-#include <iDynTree/Sensors/Sensors.h>
+#include <vector>
+#include <iDynTree/Model.h>
+#include <iDynTree/ModelExporter.h>
+#include <iDynTree/ModelLoader.h>
+#include <iDynTree/Sensors.h>
 
 #include <pybind11/operators.h>
 #include <pybind11/pybind11.h>
@@ -58,6 +61,19 @@ void iDynTreeModelIoUrdfBindings(pybind11::module& module) {
       .def_property_readonly("sensors", &ModelExporter::sensors)
       .def_property_readonly("options", &ModelExporter::exportingOptions)
       .def("export_model_to_string", &ExporterHelper::exportAsString);
+
+  py::class_<ModelLoader>(module, "ModelLoader")
+      .def(py::init())
+      .def("load_model_from_file",
+           [](ModelLoader* this_, const std::string& filename) {
+             return this_->loadModelFromFile(filename);
+           })
+      .def("load_reduced_model_from_full_model",
+           [](ModelLoader* this_, const Model& model,
+              const std::vector<std::string>& joints) {
+             return this_->loadReducedModelFromFullModel(model, joints);
+           })
+      .def_property_readonly("model", &ModelLoader::model);
 }
 
 }  // namespace bindings
