@@ -1,18 +1,11 @@
-/*
- * Copyright (C) 2015 Fondazione Istituto Italiano di Tecnologia
- *
- * Licensed under either the GNU Lesser General Public License v3.0 :
- * https://www.gnu.org/licenses/lgpl-3.0.html
- * or the GNU Lesser General Public License v2.1 :
- * https://www.gnu.org/licenses/old-licenses/lgpl-2.1.html
- * at your option.
- */
+// SPDX-FileCopyrightText: Fondazione Istituto Italiano di Tecnologia (IIT)
+// SPDX-License-Identifier: BSD-3-Clause
 
-#include <iDynTree/Core/Twist.h>
-#include <iDynTree/Core/Wrench.h>
-#include <iDynTree/Core/SpatialAcc.h>
-#include <iDynTree/Core/SpatialMomentum.h>
-#include <iDynTree/Core/PrivateUtils.h>
+#include <iDynTree/Twist.h>
+#include <iDynTree/Wrench.h>
+#include <iDynTree/SpatialAcc.h>
+#include <iDynTree/SpatialMomentum.h>
+#include <iDynTree/PrivateUtils.h>
 
 namespace iDynTree
 {
@@ -42,6 +35,14 @@ Twist::Twist(const Twist& other):
 
 }
 
+Twist& Twist::operator=(const Twist &other)
+{
+    this->getLinearVec3() = other.getLinearVec3();
+    this->getAngularVec3() = other.getAngularVec3();
+    return *this;
+}
+
+
 Twist Twist::operator+(const Twist& other) const
 {
     return efficient6dSum(*this,other);
