@@ -1,24 +1,17 @@
-/*
- * Copyright (C) 2015 Fondazione Istituto Italiano di Tecnologia
- *
- * Licensed under either the GNU Lesser General Public License v3.0 :
- * https://www.gnu.org/licenses/lgpl-3.0.html
- * or the GNU Lesser General Public License v2.1 :
- * https://www.gnu.org/licenses/old-licenses/lgpl-2.1.html
- * at your option.
- */
+// SPDX-FileCopyrightText: Fondazione Istituto Italiano di Tecnologia (IIT)
+// SPDX-License-Identifier: BSD-3-Clause
 
-#include <iDynTree/Core/EigenHelpers.h>
-#include <iDynTree/Core/SpatialInertia.h>
-#include <iDynTree/Core/SpatialMomentum.h>
-#include <iDynTree/Core/Wrench.h>
-#include <iDynTree/Core/Transform.h>
-#include <iDynTree/Core/Utils.h>
-#include <iDynTree/Core/TestUtils.h>
-#include <iDynTree/Core/Twist.h>
-#include <iDynTree/Core/MatrixFixSize.h>
-#include <iDynTree/Core/SpatialAcc.h>
-#include <iDynTree/Core/InertiaNonLinearParametrization.h>
+#include <iDynTree/EigenHelpers.h>
+#include <iDynTree/SpatialInertia.h>
+#include <iDynTree/SpatialMomentum.h>
+#include <iDynTree/Wrench.h>
+#include <iDynTree/Transform.h>
+#include <iDynTree/Utils.h>
+#include <iDynTree/TestUtils.h>
+#include <iDynTree/Twist.h>
+#include <iDynTree/MatrixFixSize.h>
+#include <iDynTree/SpatialAcc.h>
+#include <iDynTree/InertiaNonLinearParametrization.h>
 
 #include <Eigen/Dense>
 
@@ -451,7 +444,7 @@ int main()
     double rotInertiaData[3*3] = {10.0,0.04,0.04,
                                   0.04,20.0,0.04,
                                   0.04,0.04,24.0};
-    SpatialInertia inertia(1.0,Position(100,-5,10),RotationalInertiaRaw(rotInertiaData,3,3));
+    SpatialInertia inertia(1.0,Position(100,-5,10),RotationalInertia(rotInertiaData,3,3));
 
     checkInertiaTwistProduct(inertia,twist);
     checkInertiaTransformation(trans,inertia);
