@@ -1,20 +1,13 @@
-/*
- * Copyright (C) 2016 Fondazione Istituto Italiano di Tecnologia
- *
- * Licensed under either the GNU Lesser General Public License v3.0 :
- * https://www.gnu.org/licenses/lgpl-3.0.html
- * or the GNU Lesser General Public License v2.1 :
- * https://www.gnu.org/licenses/old-licenses/lgpl-2.1.html
- * at your option.
- */
-#include "iDynTree/Estimation/BerdySparseMAPSolver.h"
-#include "iDynTree/Estimation/BerdyHelper.h"
+// SPDX-FileCopyrightText: Fondazione Istituto Italiano di Tecnologia (IIT)
+// SPDX-License-Identifier: BSD-3-Clause
+#include "iDynTree/BerdySparseMAPSolver.h"
+#include "iDynTree/BerdyHelper.h"
 
-#include <iDynTree/Core/VectorDynSize.h>
-#include <iDynTree/Core/VectorFixSize.h>
-#include <iDynTree/Core/SparseMatrix.h>
-#include <iDynTree/Core/EigenHelpers.h>
-#include <iDynTree/Core/EigenSparseHelpers.h>
+#include <iDynTree/VectorDynSize.h>
+#include <iDynTree/VectorFixSize.h>
+#include <iDynTree/SparseMatrix.h>
+#include <iDynTree/EigenHelpers.h>
+#include <iDynTree/EigenSparseHelpers.h>
 
 #include <Eigen/SparseCore>
 #include <Eigen/SparseCholesky>
@@ -92,6 +85,7 @@ namespace iDynTree {
     void BerdySparseMAPSolver::setDynamicsConstraintsPriorCovariance(const iDynTree::SparseMatrix<iDynTree::ColumnMajor>& covariance)
     {
         assert(m_pimpl);
+        assert(m_pimpl->berdy.getOptions().berdyVariant!=BERDY_FLOATING_BASE_NON_COLLOCATED_EXT_WRENCHES);
         assert(covariance.rows() == m_pimpl->priorDynamicsConstraintsCovarianceInverse.rows()
                && covariance.columns() == m_pimpl->priorDynamicsConstraintsCovarianceInverse.columns());
         BerdySparseMAPSolver::BerdySparseMAPSolverPimpl::invertSparseMatrix(covariance, m_pimpl->priorDynamicsConstraintsCovarianceInverse);
@@ -257,32 +251,42 @@ namespace iDynTree {
 
         // Intermediate quantities
 
-        // Covariance matrix of the prior of the dynamics: var[p(d)], Eq. 10a
-        //TODO: find a way to map to iDynTree::SparseMatrix
-        covarianceDynamicsPriorInverse
-        //    toEigen(m_intermediateQuantities.covarianceDynamicsPriorInverse)
-        //Better to assign the "sum" before, and adding the product part later
-        = toEigen(priorDynamicsRegularizationCovarianceInverse);
+        if(berdy.getOptions().berdyVariant!=BERDY_FLOATING_BASE_NON_COLLOCATED_EXT_WRENCHES)
+        {
+            // Covariance matrix of the prior of the dynamics: var[p(d)], Eq. 10a
+            //TODO: find a way to map to iDynTree::SparseMatrix
+            covarianceDynamicsPriorInverse
+            //    toEigen(m_intermediateQuantities.covarianceDynamicsPriorInverse)
+            //Better to assign the "sum" before, and adding the product part later
+            = toEigen(priorDynamicsRegularizationCovarianceInverse);
 
-        covarianceDynamicsPriorInverse += toEigen(dynamicsConstraintsMatrix).transpose() * toEigen(priorDynamicsConstraintsCovarianceInverse) * toEigen(dynamicsConstraintsMatrix);
+            covarianceDynamicsPriorInverse += toEigen(dynamicsConstraintsMatrix).transpose() * toEigen(priorDynamicsConstraintsCovarianceInverse) * toEigen(dynamicsConstraintsMatrix);
 
-        // decompose m_covarianceDynamicsPriorInverse
-        if (computePermutation) {
-            covarianceDynamicsPriorInverseDecomposition.analyzePattern(covarianceDynamicsPriorInverse);
+            // decompose m_covarianceDynamicsPriorInverse
+            if (computePermutation) {
+                covarianceDynamicsPriorInverseDecomposition.analyzePattern(covarianceDynamicsPriorInverse);
+            }
+            //    m_intermediateQuantities.covarianceDynamicsPriorInverseDecomposition.factorize(toEigen(m_intermediateQuantities.covarianceDynamicsPriorInverse));
+            covarianceDynamicsPriorInverseDecomposition.factorize(covarianceDynamicsPriorInverse);
+
+            // Expected value of the prior of the dynamics: E[p(d)], Eq. 10b
+            toEigen(expectedDynamicsPriorRHS) = toEigen(priorDynamicsRegularizationCovarianceInverse) * toEigen(priorDynamicsRegularizationExpectedValue) - toEigen(dynamicsConstraintsMatrix).transpose() * toEigen(priorDynamicsConstraintsCovarianceInverse) * toEigen(dynamicsConstraintsBias);
+
+            toEigen(expectedDynamicsPrior) =
+            covarianceDynamicsPriorInverseDecomposition.solve(toEigen(expectedDynamicsPriorRHS));
         }
-        //    m_intermediateQuantities.covarianceDynamicsPriorInverseDecomposition.factorize(toEigen(m_intermediateQuantities.covarianceDynamicsPriorInverse));
-        covarianceDynamicsPriorInverseDecomposition.factorize(covarianceDynamicsPriorInverse);
-
-        // Expected value of the prior of the dynamics: E[p(d)], Eq. 10b
-        toEigen(expectedDynamicsPriorRHS) = toEigen(priorDynamicsRegularizationCovarianceInverse) * toEigen(priorDynamicsRegularizationExpectedValue) - toEigen(dynamicsConstraintsMatrix).transpose() * toEigen(priorDynamicsConstraintsCovarianceInverse) * toEigen(dynamicsConstraintsBias);
-
-        toEigen(expectedDynamicsPrior) =
-        covarianceDynamicsPriorInverseDecomposition.solve(toEigen(expectedDynamicsPriorRHS));
-
+        else
+        {
+            // Modified eq. 10a and 10b without the dynamics constraints
+            covarianceDynamicsPriorInverse = toEigen(priorDynamicsRegularizationCovarianceInverse);
+            expectedDynamicsPrior = priorDynamicsRegularizationExpectedValue;
+        }
+        
         // Final result: covariance matrix of the whole-body dynamics, Eq. 11a
         //TODO: find a way to map to iDynTree::SparseMatrix
-        covarianceDynamicsAPosterioriInverse = covarianceDynamicsPriorInverse;
-        covarianceDynamicsAPosterioriInverse += toEigen(measurementsMatrix).transpose() * toEigen(priorMeasurementsCovarianceInverse) * toEigen(measurementsMatrix);
+        covarianceDynamicsAPosterioriInverse = toEigen(measurementsMatrix).transpose() * toEigen(priorMeasurementsCovarianceInverse) * toEigen(measurementsMatrix);
+        covarianceDynamicsAPosterioriInverse += covarianceDynamicsPriorInverse;
+
 
         // decompose m_covarianceDynamicsAPosterioriInverse
         if (computePermutation) {
@@ -293,7 +297,9 @@ namespace iDynTree {
         covarianceDynamicsAPosterioriInverseDecomposition.factorize(covarianceDynamicsAPosterioriInverse);
 
         // Final result: expected value of the whole-body dynamics, Eq. 11b
-        toEigen(expectedDynamicsAPosterioriRHS) = (toEigen(measurementsMatrix).transpose() * toEigen(priorMeasurementsCovarianceInverse) * (toEigen(measurements) - toEigen(measurementsBias)) + covarianceDynamicsPriorInverse * toEigen(expectedDynamicsPrior));
+        toEigen(expectedDynamicsAPosterioriRHS) = toEigen(measurementsMatrix).transpose() * toEigen(priorMeasurementsCovarianceInverse) * (toEigen(measurements) - toEigen(measurementsBias));
+        toEigen(expectedDynamicsAPosterioriRHS) += covarianceDynamicsPriorInverse * toEigen(expectedDynamicsPrior);
+        
         toEigen(expectedDynamicsAPosteriori) =
         covarianceDynamicsAPosterioriInverseDecomposition.solve(toEigen(expectedDynamicsAPosterioriRHS));
     }
