@@ -1,38 +1,31 @@
-/*
- * Copyright (C) 2016 Fondazione Istituto Italiano di Tecnologia
- *
- * Licensed under either the GNU Lesser General Public License v3.0 :
- * https://www.gnu.org/licenses/lgpl-3.0.html
- * or the GNU Lesser General Public License v2.1 :
- * https://www.gnu.org/licenses/old-licenses/lgpl-2.1.html
- * at your option.
- */
+// SPDX-FileCopyrightText: Fondazione Istituto Italiano di Tecnologia (IIT)
+// SPDX-License-Identifier: BSD-3-Clause
 
-#include <iDynTree/Estimation/ExtWrenchesAndJointTorquesEstimator.h>
-#include <iDynTree/Estimation/ExternalWrenchesEstimation.h>
+#include <iDynTree/ExtWrenchesAndJointTorquesEstimator.h>
+#include <iDynTree/ExternalWrenchesEstimation.h>
 
-#include <iDynTree/Core/EigenHelpers.h>
-#include <iDynTree/Core/EigenMathHelpers.h>
-#include <iDynTree/Core/SpatialMomentum.h>
-#include <iDynTree/Core/ClassicalAcc.h>
+#include <iDynTree/EigenHelpers.h>
+#include <iDynTree/EigenMathHelpers.h>
+#include <iDynTree/SpatialMomentum.h>
+#include <iDynTree/ClassicalAcc.h>
 
-#include <iDynTree/Model/Model.h>
-#include <iDynTree/Model/Traversal.h>
-#include <iDynTree/Model/SubModel.h>
-#include <iDynTree/Model/LinkState.h>
-#include <iDynTree/Model/JointState.h>
-#include <iDynTree/Model/ContactWrench.h>
-#include <iDynTree/Model/Dynamics.h>
-#include <iDynTree/Model/ModelTransformers.h>
-#include <iDynTree/Sensors/ModelSensorsTransformers.h>
+#include <iDynTree/Model.h>
+#include <iDynTree/Traversal.h>
+#include <iDynTree/SubModel.h>
+#include <iDynTree/LinkState.h>
+#include <iDynTree/JointState.h>
+#include <iDynTree/ContactWrench.h>
+#include <iDynTree/Dynamics.h>
+#include <iDynTree/ModelTransformers.h>
+#include <iDynTree/ModelSensorsTransformers.h>
 
-#include <iDynTree/Sensors/Sensors.h>
-#include <iDynTree/Sensors/SixAxisForceTorqueSensor.h>
-#include <iDynTree/Sensors/PredictSensorsMeasurements.h>
+#include <iDynTree/Sensors.h>
+#include <iDynTree/SixAxisForceTorqueSensor.h>
+#include <iDynTree/PredictSensorsMeasurements.h>
 
-#include <iDynTree/ModelIO/ModelLoader.h>
+#include <iDynTree/ModelLoader.h>
 
-#include <iDynTree/Core/EigenHelpers.h>
+#include <iDynTree/EigenHelpers.h>
 
 #include <sstream>
 
@@ -42,12 +35,13 @@ namespace iDynTree
 ExtWrenchesAndJointTorquesEstimator::ExtWrenchesAndJointTorquesEstimator():
     m_model(),
     m_submodels(),
-    m_sensors(),
     m_isModelValid(false),
     m_isKinematicsUpdated(false),
     m_dynamicTraversal(),
     m_kinematicTraversals(),
     m_jointPos(),
+    m_jointVel(),
+    m_jointAcc(),
     m_linkVels(),
     m_linkProperAccs(),
     m_linkNetExternalWrenches(),
@@ -82,15 +76,23 @@ void getFTJointNames(const SensorsList & _sensors,
 bool ExtWrenchesAndJointTorquesEstimator::setModelAndSensors(const Model& _model,
                                                              const SensorsList& _sensors)
 {
-    // \todo TODO add isConsistent methods to Model and SensorList class
+    Model modelCopy = _model;
+    modelCopy.sensors() = _sensors;
+
+    return setModel(modelCopy);
+}
+
+bool ExtWrenchesAndJointTorquesEstimator::setModel(const Model& _model)
+{
     m_model = _model;
-    m_sensors = _sensors;
 
     // resize the data structures
     m_model.computeFullTreeTraversal(m_dynamicTraversal);
     m_kinematicTraversals.resize(m_model);
 
-
+    m_jointPos.resize(m_model);
+    m_jointVel.resize(m_model);
+    m_jointAcc.resize(m_model);
     m_linkVels.resize(m_model);
     m_linkProperAccs.resize(m_model);
     m_linkIntWrenches.resize(m_model);
@@ -99,7 +101,7 @@ bool ExtWrenchesAndJointTorquesEstimator::setModelAndSensors(const Model& _model
 
     // create submodel structure
     std::vector<std::string> ftJointNames;
-    getFTJointNames(m_sensors,ftJointNames);
+    getFTJointNames(m_model.sensors(),ftJointNames);
     bool ok = m_submodels.splitModelAlongJoints(m_model,m_dynamicTraversal,ftJointNames);
 
     if( !ok )
@@ -180,7 +182,7 @@ const Model& ExtWrenchesAndJointTorquesEstimator::model() const
 
 const SensorsList& ExtWrenchesAndJointTorquesEstimator::sensors() const
 {
-    return m_sensors;
+    return m_model.sensors();
 }
 
 const SubModelDecomposition& ExtWrenchesAndJointTorquesEstimator::submodels() const
@@ -189,9 +191,9 @@ const SubModelDecomposition& ExtWrenchesAndJointTorquesEstimator::submodels() co
 }
 
 
-bool ExtWrenchesAndJointTorquesEstimator::updateKinematicsFromFixedBase(const JointPosDoubleArray& jointPos,
-                                                                        const JointDOFsDoubleArray& jointVel,
-                                                                        const JointDOFsDoubleArray& jointAcc,
+bool ExtWrenchesAndJointTorquesEstimator::updateKinematicsFromFixedBase(const VectorDynSize& jointPos,
+                                                                        const VectorDynSize& jointVel,
+                                                                        const VectorDynSize& jointAcc,
                                                                         const FrameIndex& fixedFrame,
                                                                         const Vector3& gravity)
 {
@@ -213,9 +215,10 @@ bool ExtWrenchesAndJointTorquesEstimator::updateKinematicsFromFixedBase(const Jo
     return updateKinematicsFromFloatingBase(jointPos,jointVel,jointAcc,fixedFrame,properClassicalAcceleration,zero,zero);
 }
 
-bool ExtWrenchesAndJointTorquesEstimator::updateKinematicsFromFloatingBase(const JointPosDoubleArray& jointPos,
-                                                                           const JointDOFsDoubleArray& jointVel,
-                                                                           const JointDOFsDoubleArray& jointAcc,
+
+bool ExtWrenchesAndJointTorquesEstimator::updateKinematicsFromFloatingBase(const VectorDynSize& jointPos,
+                                                                           const VectorDynSize& jointVel,
+                                                                           const VectorDynSize& jointAcc,
                                                                            const FrameIndex& floatingFrame,
                                                                            const Vector3& properClassicalLinearAcceleration,
                                                                            const Vector3& angularVel,
@@ -234,6 +237,26 @@ bool ExtWrenchesAndJointTorquesEstimator::updateKinematicsFromFloatingBase(const
         return false;
     }
 
+    if (m_jointPos.size() != jointPos.size())
+    {
+        reportError("ExtWrenchesAndJointTorquesEstimator","updateKinematicsFromFloatingBase","Wrong size of input joint positions.");
+        return false;
+    }
+
+    if (m_jointVel.size() != jointVel.size())
+    {
+        reportError("ExtWrenchesAndJointTorquesEstimator","updateKinematicsFromFloatingBase","Wrong size of input joint velocities.");
+    }
+
+    if (m_jointAcc.size() != jointAcc.size())
+    {
+        reportError("ExtWrenchesAndJointTorquesEstimator","updateKinematicsFromFloatingBase","Wrong size of input joint accelerations.");
+    }
+
+    m_jointPos = jointPos;
+    m_jointVel = jointVel;
+    m_jointAcc = jointAcc;
+
     // Get link of the specified frame
     LinkIndex floatingLinkIndex = m_model.getFrameLink(floatingFrame);
 
@@ -257,16 +280,15 @@ bool ExtWrenchesAndJointTorquesEstimator::updateKinematicsFromFloatingBase(const
     base_acc_link = link_H_frame*base_acc_frame;
     base_classical_acc_link.fromSpatial(base_acc_link,base_vel_link);
 
+
     // Propagate the kinematics information
     bool ok = dynamicsEstimationForwardVelAccKinematics(m_model,m_kinematicTraversals.getTraversalWithLinkAsBase(m_model,floatingLinkIndex),
                                                         base_classical_acc_link.getLinearVec3(),
                                                         base_vel_link.getAngularVec3(),
                                                         base_classical_acc_link.getAngularVec3(),
-                                                        jointPos,jointVel,jointAcc,
+                                                        m_jointPos,m_jointVel,m_jointAcc,
                                                         m_linkVels,m_linkProperAccs);
 
-    // Store joint positions
-    m_jointPos = jointPos;
 
     m_isKinematicsUpdated = ok;
     return ok;
@@ -333,7 +355,7 @@ bool ExtWrenchesAndJointTorquesEstimator::computeExpectedFTSensorsMeasurements(c
     /**
      * Simulate FT sensor measurements
      */
-    predictSensorsMeasurementsFromRawBuffers(m_model,m_sensors,m_dynamicTraversal,
+    predictSensorsMeasurementsFromRawBuffers(m_model,m_dynamicTraversal,
                                              m_linkVels,m_linkProperAccs,m_linkIntWrenches,predictedMeasures);
 
 
@@ -346,6 +368,197 @@ bool ExtWrenchesAndJointTorquesEstimator::computeExpectedFTSensorsMeasurements(c
     return ok;
 }
 
+Wrench computeSubModelMatrixRelatingFTSensorsMeasuresAndKinematics_ComputebHelper(const Model& model,
+                                                              const Traversal& subModelTraversal,
+                                                              const JointPosDoubleArray & jointPos,
+                                                              const LinkVelArray& linkVel,
+                                                              const LinkAccArray& linkProperAcc,
+                                                                    estimateExternalWrenchesBuffers& bufs)
+{
+    // First compute the known term of the estimation for each link:
+    // this loop is similar to the dynamic phase of the RNEA
+    // \todo pimp up performance as done in RNEADynamicPhase
+     for(int traversalEl = subModelTraversal.getNrOfVisitedLinks()-1; traversalEl >= 0; traversalEl--)
+     {
+         LinkConstPtr visitedLink = subModelTraversal.getLink(traversalEl);
+         LinkIndex    visitedLinkIndex = visitedLink->getIndex();
+         LinkConstPtr parentLink  = subModelTraversal.getParentLink(traversalEl);
+
+         const iDynTree::SpatialInertia & I = visitedLink->getInertia();
+         const iDynTree::SpatialAcc     & properAcc = linkProperAcc(visitedLinkIndex);
+         const iDynTree::Twist          & v = linkVel(visitedLinkIndex);
+         bufs.b_contacts_subtree(visitedLinkIndex) = I*properAcc + v*(I*v);
+
+         // Iterate on childs of visitedLink
+         // We obtain all the children as all the neighbors of the link, except
+         // for its parent
+         // \todo TODO this point is definitly Tree-specific
+         // \todo TODO this "get child" for is duplicated in the code, we
+         //            should try to consolidate it
+         for(unsigned int neigh_i=0; neigh_i < model.getNrOfNeighbors(visitedLinkIndex); neigh_i++)
+         {
+             LinkIndex neighborIndex = model.getNeighbor(visitedLinkIndex,neigh_i).neighborLink;
+             // Check if this neighbor is a child of the link according to this traversal
+             if( subModelTraversal.isParentOf(visitedLinkIndex,neighborIndex) )
+             {
+                 LinkIndex childIndex = neighborIndex;
+                 IJointConstPtr neighborJoint = model.getJoint(model.getNeighbor(visitedLinkIndex,neigh_i).neighborJoint);
+                 Transform visitedLink_X_child = neighborJoint->getTransform(jointPos,visitedLinkIndex,childIndex);
+
+                 // One term of the sum in Equation 5.20 in Featherstone 2008
+                 bufs.b_contacts_subtree(visitedLinkIndex) = bufs.b_contacts_subtree(visitedLinkIndex)
+                                                            + visitedLink_X_child*bufs.b_contacts_subtree(childIndex);
+             }
+         }
+
+         if( parentLink == 0 )
+         {
+             // If the visited link is the base of the submodel, the
+             // computed known terms is the known term of the submodel itself
+             return bufs.b_contacts_subtree(visitedLinkIndex);
+         }
+     }
+
+     // If we reach this point of the code, something is really really wrong
+     assert(false);
+     return Wrench::Zero();
+}
+
+
+// If it exists, get the link of the traversal to which the FT sensor is connected. If this link does not exists,
+// return nullptr otherwise
+// Warning: this function assumes that only one link in the traversal is connected to the FT sensors, so it is
+// suitable to be used with submodels generated by some code similar to:
+// std::vector<std::string> ftJointNames;
+// getFTJointNames(m_model.sensors(),ftJointNames);
+// bool ok = m_submodels.splitModelAlongJoints(m_model,m_dynamicTraversal,ftJointNames);
+iDynTree::LinkConstPtr getLinkOfSubModelThatIsConnectedToFTSensors(const Traversal & subModelTraversal, iDynTree::SixAxisForceTorqueSensor * ftSens)
+{
+    for(size_t traversalEl = 0; traversalEl < subModelTraversal.getNrOfVisitedLinks(); traversalEl++)
+    {
+        iDynTree::LinkConstPtr visitedLink = subModelTraversal.getLink(traversalEl);
+
+        if (ftSens->isLinkAttachedToSensor(visitedLink->getIndex()))
+        {
+            return visitedLink;
+        }
+    }
+
+    return nullptr;
+}
+
+
+bool ExtWrenchesAndJointTorquesEstimator::computeSubModelMatrixRelatingFTSensorsMeasuresAndKinematics(const LinkUnknownWrenchContacts & unknownWrenches,
+                                                                                                      std::vector<iDynTree::MatrixDynSize>& A,
+                                                                                                      std::vector<iDynTree::VectorDynSize>& b,
+                                                                                                      std::vector<std::ptrdiff_t>& subModelIDs,
+                                                                                                      std::vector<iDynTree::LinkIndex>& baseLinkIndeces)
+{
+    if( !m_isModelValid )
+    {
+        reportError("ExtWrenchesAndJointTorquesEstimator","computeExpectedFTSensorsMeasurements",
+                    "Model and sensors information not set.");
+        return false;
+    }
+
+    if( !m_isKinematicsUpdated )
+    {
+        reportError("ExtWrenchesAndJointTorquesEstimator","computeExpectedFTSensorsMeasurements",
+                    "Kinematic information not set.");
+        return false;
+    }
+
+    // Compute nrOfSubmodels without external forces, and specifically which submodel
+    subModelIDs.resize(0);
+    size_t nrOfSubModels = m_submodels.getNrOfSubModels();
+    for(size_t sm=0; sm < nrOfSubModels; sm++)
+    {
+        bool subModelHasExternalWrenchOnIt = false;
+
+        // Iterate over all links of the submodel, and check if there is any external contact
+        const Traversal & subModelTraversal = m_submodels.getTraversal(sm);
+        for(size_t traversalEl = 0; traversalEl < subModelTraversal.getNrOfVisitedLinks(); traversalEl++)
+        {
+            LinkConstPtr visitedLink = subModelTraversal.getLink(traversalEl);
+            size_t nrOfContactForLink = unknownWrenches.getNrOfContactsForLink(visitedLink->getIndex());
+
+            if (nrOfContactForLink > 0)
+            {
+                subModelHasExternalWrenchOnIt = true;
+            }
+        }
+
+        if (!subModelHasExternalWrenchOnIt)
+        {
+            subModelIDs.push_back(sm);
+        }
+    }
+
+    size_t nrOfSubModelsWithoutExtWrenches = subModelIDs.size();
+    size_t nrOfFTSensors = m_model.sensors().getNrOfSensors(iDynTree::SIX_AXIS_FORCE_TORQUE);
+
+    // Resize quantities
+    baseLinkIndeces.resize(nrOfSubModelsWithoutExtWrenches);
+    A.resize(nrOfSubModelsWithoutExtWrenches);
+    b.resize(nrOfSubModelsWithoutExtWrenches);
+
+    for(size_t l=0; l < nrOfSubModelsWithoutExtWrenches; l++)
+    {
+        A[l].resize(6, 6*nrOfFTSensors);
+        b[l].resize(6);
+    }
+
+    // Populate quantities
+    for (size_t l = 0; l < subModelIDs.size(); l++)
+    {
+        size_t sm = subModelIDs[l];
+        const Traversal & subModelTraversal = m_submodels.getTraversal(sm);
+
+        // Assign baseLinkIndeces
+        baseLinkIndeces[l] = subModelTraversal.getBaseLink()->getIndex();
+
+        // Compute b vector
+
+        // First compute the known term of the estimation for each link:
+        // this loop is similar to the dynamic phase of the RNEA
+        toEigen(b[l]) = toEigen(computeSubModelMatrixRelatingFTSensorsMeasuresAndKinematics_ComputebHelper(m_model,subModelTraversal,m_jointPos,m_linkVels,m_linkProperAccs,m_bufs));
+
+        // Compute A matrix
+        Eigen::Map< Eigen::Matrix<double,Eigen::Dynamic, Eigen::Dynamic, Eigen::RowMajor> > Aeig = toEigen(A[l]);
+        Aeig.setZero();
+
+        // As a first step, we need to compute the transform between each link and the base
+        // of its submodel (we are computing the estimation equation in the submodel base frame
+        computeTransformToTraversalBase(m_model,subModelTraversal,m_jointPos,m_bufs.subModelBase_H_link);
+
+        // Iterate over all FTs of the full model, and check if they are connected to the submodel
+        // TODO: if this O(n^2) loop turns out to be expensive, we can speed it up by caching somewhere
+        // the set of FT sensors that belong to a submodel
+        for(size_t ft=0; ft < nrOfFTSensors; ft++ )
+        {
+            ::iDynTree::SixAxisForceTorqueSensor * ftSens
+                = (::iDynTree::SixAxisForceTorqueSensor *) m_model.sensors().getSensor(::iDynTree::SIX_AXIS_FORCE_TORQUE,ft);
+
+            assert(ftSens != 0);
+
+            iDynTree::LinkConstPtr linkConnectedToFt = getLinkOfSubModelThatIsConnectedToFTSensors(subModelTraversal, ftSens);
+
+            if (linkConnectedToFt)
+            {
+                iDynTree::Matrix6x6 link_T_sens;
+                bool ok = ftSens->getWrenchAppliedOnLinkMatrix(linkConnectedToFt->getIndex(), link_T_sens);
+                IDYNTREE_UNUSED(ok);
+                assert(ok);
+                iDynTree::Transform subModelBase_T_link = m_bufs.subModelBase_H_link(linkConnectedToFt->getIndex());
+                Aeig.block<6,6>(0, 6*ft) = iDynTree::toEigen(subModelBase_T_link.asAdjointTransformWrench())*iDynTree::toEigen(link_T_sens);
+            }
+        }
+
+    }
+
+    return true;
+}
+
 bool ExtWrenchesAndJointTorquesEstimator::estimateExtWrenchesAndJointTorques(const LinkUnknownWrenchContacts& unknowns,
                                                                              const SensorsMeasurements& ftSensorsMeasures,
                                                                                    LinkContactWrenches& estimateContactWrenches,
@@ -368,7 +581,7 @@ bool ExtWrenchesAndJointTorquesEstimator::estimateExtWrenchesAndJointTorques(con
     /**
      * Compute external forces
      */
-    bool ok = estimateExternalWrenches(m_model,m_submodels,m_sensors,
+    bool ok = estimateExternalWrenches(m_model,m_submodels,m_model.sensors(),
                                        unknowns,m_jointPos,m_linkVels,m_linkProperAccs,
                                        ftSensorsMeasures,m_bufs,estimateContactWrenches);
 
