@@ -1,32 +1,29 @@
-/*
- * Copyright (C) 2015 Fondazione Istituto Italiano di Tecnologia
- *
- * Licensed under either the GNU Lesser General Public License v3.0 :
- * https://www.gnu.org/licenses/lgpl-3.0.html
- * or the GNU Lesser General Public License v2.1 :
- * https://www.gnu.org/licenses/old-licenses/lgpl-2.1.html
- * at your option.
- */
+// SPDX-FileCopyrightText: Fondazione Istituto Italiano di Tecnologia (IIT)
+// SPDX-License-Identifier: BSD-3-Clause
 
 #include "testModels.h"
-#include <iDynTree/Core/TestUtils.h>
+#include <iDynTree/TestUtils.h>
 
-#include <iDynTree/Core/Transform.h>
-#include <iDynTree/Core/Position.h>
-#include <iDynTree/Core/Twist.h>
-#include <iDynTree/Core/SpatialAcc.h>
-#include <iDynTree/Core/SpatialMomentum.h>
-#include <iDynTree/Core/VectorDynSize.h>
+#include <iDynTree/Transform.h>
+#include <iDynTree/Position.h>
+#include <iDynTree/Twist.h>
+#include <iDynTree/SpatialAcc.h>
+#include <iDynTree/SpatialMomentum.h>
+#include <iDynTree/VectorDynSize.h>
 
-#include <iDynTree/Core/EigenHelpers.h>
+#include <iDynTree/EigenHelpers.h>
 
 #include <iDynTree/KinDynComputations.h>
-#include <iDynTree/Model/Model.h>
-#include <iDynTree/Model/Traversal.h>
-#include <iDynTree/Model/JointState.h>
-#include <iDynTree/Model/FreeFloatingState.h>
+#include <iDynTree/Model.h>
+#include <iDynTree/Traversal.h>
+#include <iDynTree/JointState.h>
+#include <iDynTree/FreeFloatingState.h>
+#include <iDynTree/SubModel.h>
+#include <iDynTree/ModelTransformers.h>
 
-#include <iDynTree/ModelIO/ModelLoader.h>
+#include <iDynTree/ModelTestUtils.h>
+
+#include <iDynTree/ModelLoader.h>
 
 
 using namespace iDynTree;
@@ -50,36 +47,26 @@ int real_random_int(int initialValue, int finalValue)
 void setRandomState(iDynTree::KinDynComputations & dynComp)
 {
     size_t dofs = dynComp.getNrOfDegreesOfFreedom();
+    size_t posCoords = dynComp.model().getNrOfPosCoords();
     Transform    worldTbase;
     Twist        baseVel;
     Vector3 gravity;
 
-    iDynTree::VectorDynSize qj(dofs), dqj(dofs), ddqj(dofs);
+    iDynTree::VectorDynSize qj(posCoords), dqj(dofs), ddqj(dofs);
 
-    worldTbase = iDynTree::Transform(Rotation::RPY(random_double(),random_double(),random_double()),
-            Position(random_double(),random_double(),random_double()));
+    // Use utility functions for generating random state
+    worldTbase = getRandomTransform();
+    baseVel = getRandomTwist();
+    getRandomVector(gravity);
 
-    for(int i=0; i < 3; i++)
-    {
-        gravity(i) = random_double();
-    }
-
-    for(int i=0; i < 6; i++)
-    {
-        baseVel(i) = real_random_double();
-    }
-
-    for(size_t dof=0; dof < dofs; dof++)
-
-    {
-        qj(dof) = random_double();
-        dqj(dof) = random_double();
-        ddqj(dof) = random_double();
-    }
+    // Use model-aware joint position generation for proper handling of all joint types
+    getRandomJointPositions(qj, dynComp.model());
+    getRandomVector(dqj);
+    getRandomVector(ddqj);
 
     bool ok = dynComp.setRobotState(worldTbase,qj,baseVel,dqj,gravity);
 
-    iDynTree::VectorDynSize qj_read(dofs), dqj_read(dofs);
+    iDynTree::VectorDynSize qj_read(posCoords), dqj_read(dofs);
     Vector3 gravity_read;
     Transform    worldTbase_read;
     Twist        baseVel_read;
@@ -118,15 +105,19 @@ void testRelativeTransform(iDynTree::KinDynComputations & dynComp)
 
 void testAverageVelocityAndTotalMomentumJacobian(iDynTree::KinDynComputations & dynComp)
 {
-    iDynTree::Twist avgVel;
-    iDynTree::SpatialMomentum mom, centroidalMom;
-    iDynTree::Vector6 avgVelCheck, momCheck, centroidalMomCheck;
+    iDynTree::Twist avgVel, centroidalAvgVel;
+    iDynTree::SpatialMomentum mom, centroidalMom, computedMom, computedCentroidalMom;
+    iDynTree::Vector6 avgVelCheck, centroidalAvgVelCheck, momCheck, centroidalMomCheck;
     iDynTree::VectorDynSize nu(dynComp.getNrOfDegreesOfFreedom()+6);
+    iDynTree::SpatialInertia lockedInertia, centroidalLockedInertia;
     dynComp.getModelVel(nu);
 
     MomentumFreeFloatingJacobian momJac(dynComp.getRobotModel());
     MomentumFreeFloatingJacobian centroidalMomJac(dynComp.getRobotModel());
     FrameFreeFloatingJacobian    avgVelJac(dynComp.getRobotModel());
+    FrameFreeFloatingJacobian    centroidalAvgVelJac(dynComp.getRobotModel());
+
+    // momentum quantities
 
     avgVel = dynComp.getAverageVelocity();
     bool ok = dynComp.getAverageVelocityJacobian(avgVelJac);
@@ -138,17 +129,36 @@ void testAverageVelocityAndTotalMomentumJacobian(iDynTree::KinDynComputations &
 
     ASSERT_IS_TRUE(ok);
 
+    lockedInertia = dynComp.getRobotLockedInertia();
+    computedMom = lockedInertia * avgVel;
+
+    // centroidal quantities
+
+    centroidalAvgVel = dynComp.getCentroidalAverageVelocity();
+    ok = dynComp.getCentroidalAverageVelocityJacobian(centroidalAvgVelJac);
+
+    ASSERT_IS_TRUE(ok);
+
     centroidalMom = dynComp.getCentroidalTotalMomentum();
     ok = dynComp.getCentroidalTotalMomentumJacobian(centroidalMomJac);
     ASSERT_IS_TRUE(ok);
 
+    centroidalLockedInertia = dynComp.getCentroidalRobotLockedInertia();
+    computedCentroidalMom = centroidalLockedInertia * centroidalAvgVel;
+
     toEigen(momCheck) = toEigen(momJac)*toEigen(nu);
     toEigen(centroidalMomCheck) = toEigen(centroidalMomJac)*toEigen(nu);
     toEigen(avgVelCheck) = toEigen(avgVelJac)*toEigen(nu);
+    toEigen(centroidalAvgVelCheck) = toEigen(centroidalAvgVelJac)*toEigen(nu);
 
     ASSERT_EQUAL_VECTOR(momCheck,mom.asVector());
     ASSERT_EQUAL_VECTOR(centroidalMomCheck,centroidalMom.asVector());
+
     ASSERT_EQUAL_VECTOR(avgVelCheck,avgVel.asVector());
+    ASSERT_EQUAL_VECTOR(centroidalAvgVelCheck, centroidalAvgVel.asVector());
+
+    ASSERT_EQUAL_VECTOR(mom.asVector(), computedMom);
+    ASSERT_EQUAL_VECTOR(centroidalMom.asVector(), computedCentroidalMom);
 }
 
 inline Eigen::VectorXd toEigen(const Vector6 & baseAcc, const VectorDynSize & jntAccs)
@@ -530,9 +540,161 @@ void testInverseDynamicsWithInternalJointForceTorques(KinDynComputations & dynCo
 
 }
 
+bool isStringInVector(const std::string & str,
+                      const std::vector<std::string> & vec)
+{
+    return std::find(vec.begin(), vec.end(), str) != vec.end();
+}
+
+void getRandomSubsetOfJoints(const Model & model,
+                             size_t nrOfJointsInSubset,
+                             std::vector<std::string>& subsetOfJoints)
+{
+    while( subsetOfJoints.size() < nrOfJointsInSubset )
+    {
+        JointIndex randomJoint = (JointIndex) getRandomInteger(0,model.getNrOfJoints()-1);
+        std::string randomJointName = model.getJointName(randomJoint);
+
+        // If the random added joint is not in the vector, add it
+        if( !isStringInVector(randomJointName,subsetOfJoints) )
+        {
+            subsetOfJoints.push_back(randomJointName);
+        }
+    }
+}
+
+void testSubModelConsistency(std::string modelFilePath, const FrameVelocityRepresentation frameVelRepr)
+{
+    iDynTree::ModelLoader mdlLoader;
+    bool ok = mdlLoader.loadModelFromFile(modelFilePath);
+    ASSERT_IS_TRUE(ok);
+
+    iDynTree::KinDynComputations dynCompFullModel;
+    ok = dynCompFullModel.loadRobotModel(mdlLoader.model());
+    ASSERT_IS_TRUE(ok);
+
+    ok = dynCompFullModel.setFrameVelocityRepresentation(frameVelRepr);
+    ASSERT_IS_TRUE(ok);
+
+    setRandomState(dynCompFullModel);
+
+    Model fullModel = mdlLoader.model();
+
+    int dofsFullModel = fullModel.getNrOfDOFs();
+
+    for(size_t jnts=1; jnts < fullModel.getNrOfJoints(); jnts += 5)
+    {
+        Traversal traversal;
+        ok = fullModel.computeFullTreeTraversal(traversal);
+
+        ASSERT_IS_TRUE(ok);
+
+        // Define set of joints which split the model in submodels
+        std::vector<std::string> jointInReducedModel;
+        getRandomSubsetOfJoints(fullModel, jnts, jointInReducedModel);
+
+        iDynTree::SubModelDecomposition subModels;
+        ok = subModels.splitModelAlongJoints(fullModel, traversal, jointInReducedModel);
+        ASSERT_IS_TRUE(ok);
+
+        for(int subModelIdx = 0; subModelIdx < subModels.getNrOfSubModels(); subModelIdx++)
+        {
+            const Traversal & subModelTraversal = subModels.getTraversal(subModelIdx);
+
+            Model reducedModel;
+            ok = extractSubModel(fullModel, subModelTraversal, reducedModel);
+            ASSERT_IS_TRUE(ok);
+
+            iDynTree::KinDynComputations dynCompReducedModel;
+            ok = dynCompReducedModel.loadRobotModel(reducedModel);
+            ASSERT_IS_TRUE(ok);
+
+            ok = dynCompReducedModel.setFrameVelocityRepresentation(frameVelRepr);
+            ASSERT_IS_TRUE(ok);
+
+            // Get robot state from kinDynFullModel
+            iDynTree::VectorDynSize qjFullModel(dofsFullModel), dqjFullModel(dofsFullModel);
+            Vector3 gravity;
+            Transform    worldTbaseFullModel;
+            Twist        baseVelFullModel;
+            dynCompFullModel.getRobotState(worldTbaseFullModel, qjFullModel, baseVelFullModel, dqjFullModel, gravity);
+
+            // Get transform between base of full model and base of reduced model
+            Transform baseFullTbaseReduced;
+            baseFullTbaseReduced = dynCompFullModel.getWorldTransform(subModelTraversal.getLink(0)->getIndex());
+            Twist baseVelReducedModel;
+            baseVelReducedModel = dynCompFullModel.getFrameVel(subModelTraversal.getLink(0)->getIndex());
+
+            // Find indeces of fullModel joints corresponding to subModel joints
+            VectorDynSize idxJntReducedModelInFullModel(reducedModel.getNrOfJoints());
+
+            for(JointIndex jntIdx = 0; jntIdx < reducedModel.getNrOfJoints(); jntIdx++)
+            {
+                std::string jntName = reducedModel.getJointName(jntIdx);
+
+                idxJntReducedModelInFullModel(jntIdx) = fullModel.getJointIndex(jntName);
+            }
+
+            // Get q and dq from kinDynFullModel of joints contained in subModel
+            VectorDynSize qReducedModel(reducedModel.getNrOfDOFs()),
+                          dqReducedModel(reducedModel.getNrOfDOFs());
+
+            for(JointIndex jntIdx = 0; jntIdx < reducedModel.getNrOfJoints(); jntIdx++)
+             {
+                size_t posCoordsOffsetReducedModel = reducedModel.getJoint(jntIdx)->getPosCoordsOffset();
+                JointIndex jntIdxFullModel = idxJntReducedModelInFullModel(jntIdx);
+                size_t posCoordsOffsetFullModel = fullModel.getJoint(jntIdxFullModel)->getPosCoordsOffset();
+                for(size_t localPosCoords = 0; localPosCoords < reducedModel.getJoint(jntIdx)->getNrOfPosCoords(); localPosCoords ++)
+                {
+                    qReducedModel(posCoordsOffsetReducedModel+localPosCoords) = qjFullModel(posCoordsOffsetFullModel+localPosCoords);
+                }
+             }
+
+            for(JointIndex jntIdx = 0; jntIdx < reducedModel.getNrOfJoints(); jntIdx++)
+            {
+                size_t dofsOffsetReducedModel = reducedModel.getJoint(jntIdx)->getDOFsOffset();
+                JointIndex jntIdxFullModel = idxJntReducedModelInFullModel(jntIdx);
+                size_t dofsOffsetFullModel = fullModel.getJoint(jntIdxFullModel)->getDOFsOffset();
+                for(size_t localDofs = 0; localDofs < reducedModel.getJoint(jntIdx)->getNrOfDOFs(); localDofs++)
+                {
+                    dqReducedModel(dofsOffsetReducedModel+localDofs ) = dqjFullModel(dofsOffsetFullModel+localDofs);
+                }
+            }
+
+            ok = dynCompReducedModel.setRobotState(baseFullTbaseReduced, qReducedModel, baseVelReducedModel, dqReducedModel, gravity);
+            ASSERT_IS_TRUE(ok);
+
+            // Compare pose and velocity per each link from full model and from reduced model
+            for(FrameIndex frameIdxReducedModel = 0; frameIdxReducedModel < reducedModel.getNrOfFrames(); frameIdxReducedModel++)
+            {
+                std::string frameName = reducedModel.getFrameName(frameIdxReducedModel);
+
+                int frameIdxFullModel = fullModel.getFrameIndex(frameName);
+
+                // Frame pose from full model
+                Transform framePoseFullModel = dynCompFullModel.getWorldTransform(frameIdxFullModel);
+
+                // Frame pose from reduced model
+                Transform framePoseReducedModel = dynCompReducedModel.getWorldTransform(frameIdxReducedModel);
+
+                ASSERT_EQUAL_TRANSFORM(framePoseFullModel, framePoseReducedModel);
+
+                // Frame velicity from full model
+                Twist frameVelFullModel = dynCompFullModel.getFrameVel(frameName);
+
+                // Frame velocity from reduced model
+                Twist frameVelReducedModel = dynCompReducedModel.getFrameVel(frameName);
+
+                ASSERT_EQUAL_VECTOR(frameVelFullModel, frameVelReducedModel);
+            }
+
+        }
+    }
+}
+
 void testModelConsistency(std::string modelFilePath, const FrameVelocityRepresentation frameVelRepr)
 {
-	iDynTree::KinDynComputations dynComp;
+    iDynTree::KinDynComputations dynComp;
     iDynTree::ModelLoader mdlLoader;
     bool ok = mdlLoader.loadModelFromFile(modelFilePath);
     ok = ok && dynComp.loadRobotModel(mdlLoader.model());
@@ -553,6 +715,18 @@ void testModelConsistency(std::string modelFilePath, const FrameVelocityRepresen
 
 }
 
+void testSubModelConsistencyAllRepresentations(std::string modelName)
+{
+    std::string urdfFileName = getAbsModelPath(modelName);
+    std::cout << "Testing file " << urdfFileName <<  std::endl;
+    std::cout << "Testing MIXED_REPRESENTATION " << urdfFileName <<  std::endl;
+    testSubModelConsistency(urdfFileName,iDynTree::MIXED_REPRESENTATION);
+    std::cout << "Testing BODY_FIXED_REPRESENTATION " << urdfFileName <<  std::endl;
+    testSubModelConsistency(urdfFileName,iDynTree::BODY_FIXED_REPRESENTATION);
+    std::cout << "Testing INERTIAL_FIXED_REPRESENTATION " << urdfFileName <<  std::endl;
+    testSubModelConsistency(urdfFileName,iDynTree::INERTIAL_FIXED_REPRESENTATION);
+}
+
 void testModelConsistencyAllRepresentations(std::string modelName)
 {
     std::string urdfFileName = getAbsModelPath(modelName);
@@ -681,6 +855,14 @@ int main()
     testModelConsistencyAllRepresentations("iCubGenova02.urdf");
     testModelConsistencyAllRepresentations("icalibrate.urdf");
 
+    testSubModelConsistencyAllRepresentations("oneLink.urdf");
+    testSubModelConsistencyAllRepresentations("twoLinks.urdf");
+    testSubModelConsistencyAllRepresentations("threeLinks.urdf");
+    testSubModelConsistencyAllRepresentations("bigman.urdf");
+    testSubModelConsistencyAllRepresentations("icub_skin_frames.urdf");
+    testSubModelConsistencyAllRepresentations("iCubGenova02.urdf");
+    testSubModelConsistencyAllRepresentations("icalibrate.urdf");
+
     testSparsityPatternAllRepresentations("oneLink.urdf");
     testSparsityPatternAllRepresentations("twoLinks.urdf");
     testSparsityPatternAllRepresentations("threeLinks.urdf");
