@@ -1,24 +1,17 @@
-/*
- * Copyright (C) 2016 Fondazione Istituto Italiano di Tecnologia
- *
- * Licensed under either the GNU Lesser General Public License v3.0 :
- * https://www.gnu.org/licenses/lgpl-3.0.html
- * or the GNU Lesser General Public License v2.1 :
- * https://www.gnu.org/licenses/old-licenses/lgpl-2.1.html
- * at your option.
- */
+// SPDX-FileCopyrightText: Fondazione Istituto Italiano di Tecnologia (IIT)
+// SPDX-License-Identifier: BSD-3-Clause
 
 #include <iDynTree/InverseKinematics.h>
 #ifdef IDYNTREE_USES_IPOPT
 #include "InverseKinematicsData.h"
 #include "TransformConstraint.h"
 
-#include <iDynTree/Core/Axis.h>
-#include <iDynTree/Core/Direction.h>
-#include <iDynTree/Core/Transform.h>
-#include <iDynTree/ModelIO/ModelLoader.h>
+#include <iDynTree/Axis.h>
+#include <iDynTree/Direction.h>
+#include <iDynTree/Transform.h>
+#include <iDynTree/ModelLoader.h>
 
-#include <iDynTree/Core/EigenHelpers.h>
+#include <iDynTree/EigenHelpers.h>
 
 #include <cassert>
 #include <iostream>
@@ -104,6 +97,16 @@ namespace iDynTree {
 #endif
     }
 
+    bool InverseKinematics::setJointLimits(iDynTree::Span<const double> jointLimitsMin, iDynTree::Span<const double> jointLimitsMax)
+    {
+#ifdef IDYNTREE_USES_IPOPT
+      assert(m_pimpl);
+      return IK_PIMPL(m_pimpl)->setJointLimits(jointLimitsMin, jointLimitsMax);
+#else
+        return missingIpoptErrorReport();
+#endif
+    }
+
     bool InverseKinematics::getJointLimits(std::vector<std::pair<double, double> >& jointLimits)
     {
 #ifdef IDYNTREE_USES_IPOPT
@@ -114,6 +117,16 @@ namespace iDynTree {
 #endif
     }
 
+    bool InverseKinematics::getJointLimits(iDynTree::Span<double> jointLimitsMin, iDynTree::Span< double> jointLimitsMax)
+    {
+#ifdef IDYNTREE_USES_IPOPT
+      assert(m_pimpl);
+      return IK_PIMPL(m_pimpl)->getJointLimits(jointLimitsMin, jointLimitsMax);
+#else
+        return missingIpoptErrorReport();
+#endif
+    }
+
     void InverseKinematics::clearProblem()
     {
 #ifdef IDYNTREE_USES_IPOPT
@@ -187,7 +200,7 @@ namespace iDynTree {
         return IK_PIMPL(m_pimpl)->rotationParametrization();
 #else
         missingIpoptErrorReport();
-        return InverseKinematicsRotationParametrizationQuaternion;
+        return InverseKinematicsRotationParametrizationRollPitchYaw;
 #endif
     }
 
