@@ -1,22 +1,15 @@
-/*
- * Copyright (C) 2016 Fondazione Istituto Italiano di Tecnologia
- *
- * Licensed under either the GNU Lesser General Public License v3.0 :
- * https://www.gnu.org/licenses/lgpl-3.0.html
- * or the GNU Lesser General Public License v2.1 :
- * https://www.gnu.org/licenses/old-licenses/lgpl-2.1.html
- * at your option.
- */
+// SPDX-FileCopyrightText: Fondazione Istituto Italiano di Tecnologia (IIT)
+// SPDX-License-Identifier: BSD-3-Clause
 
 #include "InverseKinematicsData.h"
 #include "InverseKinematicsNLP.h"
 #include "TransformConstraint.h"
-#include <iDynTree/Core/Axis.h>
-#include <iDynTree/Core/Twist.h>
-#include <iDynTree/Core/ClassicalAcc.h>
-#include <iDynTree/Core/SpatialAcc.h>
-#include <iDynTree/ModelIO/ModelLoader.h>
-#include <iDynTree/Core/EigenHelpers.h>
+#include <iDynTree/Axis.h>
+#include <iDynTree/Twist.h>
+#include <iDynTree/ClassicalAcc.h>
+#include <iDynTree/SpatialAcc.h>
+#include <iDynTree/ModelLoader.h>
+#include <iDynTree/EigenHelpers.h>
 
 #include <cassert>
 #include <private/InverseKinematicsData.h>
@@ -30,7 +23,7 @@ namespace kinematics {
     InverseKinematicsData::InverseKinematicsData()
     : m_defaultTargetResolutionMode(iDynTree::InverseKinematicsTreatTargetAsConstraintNone)
     , m_dofs(0)
-    , m_rotationParametrization(iDynTree::InverseKinematicsRotationParametrizationQuaternion)
+    , m_rotationParametrization(iDynTree::InverseKinematicsRotationParametrizationRollPitchYaw)
     , m_areBaseInitialConditionsSet(false)
     , m_areJointsInitialConditionsSet(InverseKinematicsInitialConditionNotSet)
     , m_problemInitialized(false)
@@ -552,6 +545,22 @@ namespace kinematics {
         return true;
     }
 
+    bool InverseKinematicsData::setJointLimits(iDynTree::Span<const double> jointLimitsMin, iDynTree::Span<const double> jointLimitsMax)
+    {
+        // check that the dimension of the vector is correct
+        if((jointLimitsMin.size() != m_jointLimits.size()) || (jointLimitsMax.size() != m_jointLimits.size()))
+        {
+            return false;
+        }
+
+        for(size_t i=0; i < m_jointLimits.size(); i++)
+        {
+            m_jointLimits[i] = std::pair<double, double>(jointLimitsMin[i], jointLimitsMax[i]);
+        }
+
+        return true;
+    }
+
     bool InverseKinematicsData::getJointLimits(std::vector<std::pair<double, double> >& jointLimits)
     {
       // check that the dimension of the vector is correct
@@ -564,5 +573,22 @@ namespace kinematics {
       return true;
     }
 
+    bool InverseKinematicsData::getJointLimits(iDynTree::Span<double> jointLimitsMin, iDynTree::Span< double> jointLimitsMax)
+    {
+        // check that the dimension of the vector is correct
+        if((jointLimitsMin.size() != m_jointLimits.size()) || (jointLimitsMax.size() != m_jointLimits.size()))
+        {
+            return false;
+        }
+
+        for(size_t i=0; i < m_jointLimits.size(); i++)
+        {
+            jointLimitsMin[i] = m_jointLimits[i].first;
+            jointLimitsMax[i] = m_jointLimits[i].second;
+        }
+
+        return true;
+    }
+
 }
 }
