@@ -1,12 +1,5 @@
-/*
- * Copyright (C) 2016 Fondazione Istituto Italiano di Tecnologia
- *
- * Licensed under either the GNU Lesser General Public License v3.0 :
- * https://www.gnu.org/licenses/lgpl-3.0.html
- * or the GNU Lesser General Public License v2.1 :
- * https://www.gnu.org/licenses/old-licenses/lgpl-2.1.html
- * at your option.
- */
+// SPDX-FileCopyrightText: Fondazione Istituto Italiano di Tecnologia (IIT)
+// SPDX-License-Identifier: BSD-3-Clause
 //For using the M_PI macro in visual studio it
 //is necessary to define _USE_MATH_DEFINES
 #ifndef _USE_MATH_DEFINES
@@ -19,7 +12,7 @@
 #include "TransformConstraint.h"
 
 #include <Eigen/Core>
-#include <iDynTree/Core/EigenHelpers.h>
+#include <iDynTree/EigenHelpers.h>
 #include <cassert>
 #include <cmath>
 
