@@ -1,21 +1,14 @@
-/*
- * Copyright (C) 2017 Fondazione Istituto Italiano di Tecnologia
- *
- * Licensed under either the GNU Lesser General Public License v3.0 :
- * https://www.gnu.org/licenses/lgpl-3.0.html
- * or the GNU Lesser General Public License v2.1 :
- * https://www.gnu.org/licenses/old-licenses/lgpl-2.1.html
- * at your option.
- */
+// SPDX-FileCopyrightText: Fondazione Istituto Italiano di Tecnologia (IIT)
+// SPDX-License-Identifier: BSD-3-Clause
 
 #include <iDynTree/InverseKinematics.h>
 #include <iDynTree/KinDynComputations.h>
 
-#include <iDynTree/Core/Transform.h>
-#include <iDynTree/Core/TestUtils.h>
-#include <iDynTree/Model/JointState.h>
-#include <iDynTree/Model/ModelTestUtils.h>
-#include <iDynTree/ModelIO/ModelLoader.h>
+#include <iDynTree/Transform.h>
+#include <iDynTree/TestUtils.h>
+#include <iDynTree/JointState.h>
+#include <iDynTree/ModelTestUtils.h>
+#include <iDynTree/ModelLoader.h>
 
 #include "testModels.h"
 
