@@ -1,22 +1,15 @@
-/*
- * Copyright (C) 2016 Fondazione Istituto Italiano di Tecnologia
- *
- * Licensed under either the GNU Lesser General Public License v3.0 :
- * https://www.gnu.org/licenses/lgpl-3.0.html
- * or the GNU Lesser General Public License v2.1 :
- * https://www.gnu.org/licenses/old-licenses/lgpl-2.1.html
- * at your option.
- */
+// SPDX-FileCopyrightText: Fondazione Istituto Italiano di Tecnologia (IIT)
+// SPDX-License-Identifier: BSD-3-Clause
 
-#include <iDynTree/Model/DenavitHartenberg.h>
-#include <iDynTree/Model/ForwardKinematics.h>
-#include <iDynTree/Model/Traversal.h>
-#include <iDynTree/Model/RevoluteJoint.h>
-#include <iDynTree/Model/FixedJoint.h>
-#include <iDynTree/Model/LinkState.h>
-#include <iDynTree/Model/FreeFloatingState.h>
+#include <iDynTree/DenavitHartenberg.h>
+#include <iDynTree/ForwardKinematics.h>
+#include <iDynTree/Traversal.h>
+#include <iDynTree/RevoluteJoint.h>
+#include <iDynTree/FixedJoint.h>
+#include <iDynTree/LinkState.h>
+#include <iDynTree/FreeFloatingState.h>
 
-#include <iDynTree/Core/EigenHelpers.h>
+#include <iDynTree/EigenHelpers.h>
 
 
 namespace iDynTree
@@ -745,7 +738,7 @@ bool CreateModelFromDHChain(const DHChain& inputChain,
     outputModel = Model();
 
     // All the inertial will be of one kg in the origin
-    iDynTree::SpatialInertia inertiaDefault(1.0,Position::Zero(),RotationalInertiaRaw::Zero());
+    iDynTree::SpatialInertia inertiaDefault(1.0,Position::Zero(),RotationalInertia::Zero());
     iDynTree::Link linkDefault;
     linkDefault.setInertia(inertiaDefault);
 
