@@ -1,27 +1,26 @@
-/*
- * Copyright (C) 2015 Fondazione Istituto Italiano di Tecnologia
- *
- * Licensed under either the GNU Lesser General Public License v3.0 :
- * https://www.gnu.org/licenses/lgpl-3.0.html
- * or the GNU Lesser General Public License v2.1 :
- * https://www.gnu.org/licenses/old-licenses/lgpl-2.1.html
- * at your option.
- */
+// SPDX-FileCopyrightText: Fondazione Istituto Italiano di Tecnologia (IIT)
+// SPDX-License-Identifier: BSD-3-Clause
 
-#include <iDynTree/Model/Model.h>
-#include <iDynTree/Model/Traversal.h>
+#include <iDynTree/Model.h>
+#include <iDynTree/Traversal.h>
+#include <iDynTree/SolidShapes.h>
 
-#include <iDynTree/Core/VectorDynSize.h>
-#include <iDynTree/Core/EigenHelpers.h>
+#include <iDynTree/VectorDynSize.h>
+#include <iDynTree/EigenHelpers.h>
 
 #include <cassert>
 #include <deque>
 #include <sstream>
+#include <string>
+
 
 namespace iDynTree
 {
 
-Model::Model(): defaultBaseLink(LINK_INVALID_INDEX), nrOfPosCoords(0), nrOfDOFs(0)
+Model::Model()
+    : defaultBaseLink(LINK_INVALID_INDEX)
+    , nrOfPosCoords(0)
+    , nrOfDOFs(0)
 {
 
 }
@@ -31,6 +30,8 @@ void Model::copy(const Model& other)
     // reset the base link, the real one will be copied later
     this->defaultBaseLink = LINK_INVALID_INDEX;
 
+    this->packageDirs = other.packageDirs;
+
     // Add all the links, preserving the numbering
     for(unsigned int lnk=0; lnk < other.getNrOfLinks(); lnk++ )
     {
@@ -62,6 +63,9 @@ void Model::copy(const Model& other)
     // Copy the solid shapes
     this->m_collisionSolidShapes = other.m_collisionSolidShapes;
     this->m_visualSolidShapes    = other.m_visualSolidShapes;
+
+    // Copy the sensors
+    this->m_sensors = other.m_sensors;
 }
 
 
@@ -98,6 +102,7 @@ void Model::destroy()
     additionalFramesLinks.resize(0);
     frameNames.resize(0);
     neighbors.resize(0);
+    packageDirs.clear();
 }
 
 Model::~Model()
@@ -110,6 +115,34 @@ Model Model::copy() const
     return Model(*this);
 }
 
+const std::vector<std::string>& Model::getPackageDirs() const
+{
+    return this->packageDirs;
+}
+
+void Model::setPackageDirs(const std::vector<std::string>& packageDirs)
+{
+    this->packageDirs = packageDirs;
+
+    auto updatePackageDirs = [this](ModelSolidShapes& modelShapes) -> void
+                             {
+                                 for (auto& shapes : modelShapes.getLinkSolidShapes())
+                                 {
+                                     for (auto& shape : shapes)
+                                     {
+                                         if (shape != nullptr && shape->isExternalMesh())
+                                         {
+                                             shape->asExternalMesh()->setPackageDirs(this->packageDirs);
+                                         }
+                                     }
+                                 }
+
+                             };
+
+    updatePackageDirs(this->collisionSolidShapes());
+    updatePackageDirs(this->visualSolidShapes());
+}
+
 size_t Model::getNrOfLinks() const
 {
     return links.size();
@@ -534,7 +567,7 @@ JointIndex Model::insertLinkToExistingJointAndAddJointForDisplacedLink(const std
 
 size_t Model::getNrOfPosCoords() const
 {
-    return nrOfDOFs;
+    return nrOfPosCoords;
 }
 
 size_t Model::getNrOfDOFs() const
@@ -836,9 +869,10 @@ bool Model::computeFullTreeTraversal(Traversal & traversal, const LinkIndex trav
         }
     }
 
-    // At this point the traversal should contain all the links
-    // of the model
-    assert(traversal.getNrOfVisitedLinks() == this->getNrOfLinks());
+    // At this point the traversal should contain part of the links of the model
+    // (not all, as it is a subset if the links of the model are not all connected by joints )
+    // See https://github.com/robotology/idyntree/pull/914
+    assert(traversal.getNrOfVisitedLinks() <= this->getNrOfLinks());
 
     return true;
 }
@@ -901,6 +935,16 @@ const ModelSolidShapes& Model::collisionSolidShapes() const
     return m_collisionSolidShapes;
 }
 
+SensorsList& Model::sensors()
+{
+    return m_sensors;
+}
+
+const SensorsList& Model::sensors() const
+{
+    return m_sensors;
+}
+
 std::string Model::toString() const
 {
     std::stringstream ss;
@@ -930,4 +974,10 @@ std::string Model::toString() const
 
     return ss.str();
 }
+
+bool Model::isValid() const
+{
+    return m_sensors.isConsistent(*this);
+}
+
 }
