@@ -1,17 +1,10 @@
-/*
- * Copyright (C) 2015 Fondazione Istituto Italiano di Tecnologia
- *
- * Licensed under either the GNU Lesser General Public License v3.0 :
- * https://www.gnu.org/licenses/lgpl-3.0.html
- * or the GNU Lesser General Public License v2.1 :
- * https://www.gnu.org/licenses/old-licenses/lgpl-2.1.html
- * at your option.
- */
+// SPDX-FileCopyrightText: Fondazione Istituto Italiano di Tecnologia (IIT)
+// SPDX-License-Identifier: BSD-3-Clause
 
-#include <iDynTree/Model/Link.h>
+#include <iDynTree/Link.h>
 
-#include <iDynTree/Core/Position.h>
-#include <iDynTree/Core/TestUtils.h>
+#include <iDynTree/Position.h>
+#include <iDynTree/TestUtils.h>
 
 #include <cstdio>
 #include <cstdlib>
@@ -23,7 +16,7 @@ int main()
     double rotInertiaData[3*3] = {10.0,0.0,0.0,
                                   0.0,20.0,0.0,
                                   0.0,0.0,30.0};
-    SpatialInertia settedInertia(1.0,Position(100,0,0),RotationalInertiaRaw(rotInertiaData,3,3));
+    SpatialInertia settedInertia(1.0,Position(100,0,0),RotationalInertia(rotInertiaData,3,3));
 
     Link link;
 
