@@ -1,32 +1,27 @@
-/*
- * Copyright (C) 2015 Fondazione Istituto Italiano di Tecnologia
- *
- * Licensed under either the GNU Lesser General Public License v3.0 :
- * https://www.gnu.org/licenses/lgpl-3.0.html
- * or the GNU Lesser General Public License v2.1 :
- * https://www.gnu.org/licenses/old-licenses/lgpl-2.1.html
- * at your option.
- */
+// SPDX-FileCopyrightText: Fondazione Istituto Italiano di Tecnologia (IIT)
+// SPDX-License-Identifier: BSD-3-Clause
 
-#include <iDynTree/Model/FixedJoint.h>
-#include <iDynTree/Model/RevoluteJoint.h>
-#include <iDynTree/Model/PrismaticJoint.h>
-#include <iDynTree/Model/Model.h>
-#include <iDynTree/Model/ModelTestUtils.h>
-#include <iDynTree/Model/Traversal.h>
+#include <iDynTree/FixedJoint.h>
+#include <iDynTree/RevoluteJoint.h>
+#include <iDynTree/PrismaticJoint.h>
+#include <iDynTree/Model.h>
+#include <iDynTree/ModelTestUtils.h>
+#include <iDynTree/Traversal.h>
 
-#include <iDynTree/Core/TestUtils.h>
+#include <iDynTree/TestUtils.h>
 
 #include <algorithm>
 #include <cassert>
 #include <cstdio>
 #include <cstdlib>
+#include <cmath>
 
 // For modelTransformsers testing
-#include <iDynTree/Model/ModelTransformers.h>
-#include <iDynTree/Model/ForwardKinematics.h>
-#include <iDynTree/Model/Dynamics.h>
-#include <iDynTree/Model/FreeFloatingState.h>
+#include <iDynTree/ModelTransformers.h>
+#include <iDynTree/ForwardKinematics.h>
+#include <iDynTree/Dynamics.h>
+#include <iDynTree/FreeFloatingState.h>
+#include <iDynTree/SubModel.h>
 
 using namespace iDynTree;
 
@@ -98,9 +93,55 @@ void getRandomSubsetOfJoints(const Model & model,
     }
 }
 
+void getRandomJointPositionsForJointsNotInReducedModels(const Model & fullModel,
+                                                       const std::vector<std::string>& subsetOfJointsInReducedModel,
+                                                       std::unordered_map<std::string, std::vector<double>>& removedJointPositions,
+                                                       FreeFloatingPos& fullModelPos)
+{
+    for(JointIndex jntIndex = 0; jntIndex < fullModel.getNrOfJoints(); jntIndex++)
+    {
+        // Check if joint is in reduced model
+        std::string jointName = fullModel.getJointName(jntIndex);
+
+        // Set random positions for joints not in the reduced model
+        if (!isStringInVector(jointName, subsetOfJointsInReducedModel))
+        {
+            // Get the number of position coordinates for this joint
+            size_t nrOfPosCoords = fullModel.getJoint(jntIndex)->getNrOfPosCoords();
+
+            if (nrOfPosCoords > 0)
+            {
+                // Create a vector to store all position coordinates for this joint
+                std::vector<double> jointPosCoords(nrOfPosCoords);
+
+                // Set random values for all position coordinates in the full model
+                for (size_t coordIdx = 0; coordIdx < nrOfPosCoords; coordIdx++)
+                {
+                    double randomValue = iDynTree::getRandomDouble();
+                    fullModelPos.jointPos()(fullModel.getJoint(jntIndex)->getPosCoordsOffset() + coordIdx) = randomValue;
+                    jointPosCoords[coordIdx] = randomValue;
+                }
+
+                // Use normalizeJointPosCoords to make the coordinates valid for the joint type
+                // This handles different joint types (RevoluteSO2, Revolute, Prismatic, etc.) appropriately
+                fullModel.getJoint(jntIndex)->normalizeJointPosCoords(fullModelPos.jointPos());
+
+                // After normalization, extract the normalized values for the removedJointPositions map
+                for (size_t coordIdx = 0; coordIdx < nrOfPosCoords; coordIdx++)
+                {
+                    jointPosCoords[coordIdx] = fullModelPos.jointPos()(fullModel.getJoint(jntIndex)->getPosCoordsOffset() + coordIdx);
+                }
+
+                // Store the normalized position coordinates in the map
+                removedJointPositions[jointName] = jointPosCoords;
+            }
+        }
+    }
+}
+
 class RNEAHelperClass
 {
-private:
+public:
     Model model;
     LinkVelArray linkVels;
     LinkAccArray linkAccs;
@@ -108,7 +149,6 @@ private:
     LinkInternalWrenches linkIntF;
     Traversal traversal;
 
-public:
     RNEAHelperClass(const Model& _model): model(_model),
                                           linkVels(_model),
                                           linkAccs(_model),
@@ -155,10 +195,48 @@ void copyFromReducedToFull(const vectorType & reducedVector,
             assert(jntInFullModel->getNrOfDOFs() > 0);
             assert(fullVector.size() == fullModel.getNrOfPosCoords());
             assert(reducedVector.size() == reducedModel.getNrOfPosCoords());
-            assert(jntInFullModel->getPosCoordsOffset() < fullVector.size());
-            assert(jnt->getPosCoordsOffset() < reducedVector.size());
+            assert(jntInFullModel->getPosCoordsOffset() + jntInFullModel->getNrOfPosCoords() <= fullVector.size());
+            assert(jnt->getPosCoordsOffset() + jnt->getNrOfPosCoords() <= reducedVector.size());
 
-            fullVector(jntInFullModel->getPosCoordsOffset()) = reducedVector(jnt->getPosCoordsOffset());
+            // Copy all position coordinates for this joint
+            for (size_t i = 0; i < jnt->getNrOfPosCoords(); i++)
+            {
+                fullVector(jntInFullModel->getPosCoordsOffset() + i) = reducedVector(jnt->getPosCoordsOffset() + i);
+            }
+        }
+    }
+}
+
+/**
+ * Copy a vector of DOFs from the reduced model to the full model.
+ * This function should be used for joint torques, velocities, and accelerations.
+ */
+template<typename vectorType>
+void copyFromReducedToFullDOFs(const vectorType & reducedVector,
+                            vectorType & fullVector,
+                      const Model & reducedModel,
+                      const Model & fullModel)
+{
+    for(JointIndex jntReduced = 0; jntReduced < reducedModel.getNrOfJoints(); jntReduced++ )
+    {
+        IJointConstPtr jnt = reducedModel.getJoint(jntReduced);
+        std::string jointName = reducedModel.getJointName(jntReduced);
+
+        if( jnt->getNrOfDOFs() > 0 )
+        {
+            IJointConstPtr jntInFullModel = fullModel.getJoint(fullModel.getJointIndex(jointName));
+
+            assert(jntInFullModel->getNrOfDOFs() > 0);
+            assert(fullVector.size() == fullModel.getNrOfDOFs());
+            assert(reducedVector.size() == reducedModel.getNrOfDOFs());
+            assert(jntInFullModel->getDOFsOffset() + jntInFullModel->getNrOfDOFs() <= fullVector.size());
+            assert(jnt->getDOFsOffset() + jnt->getNrOfDOFs() <= reducedVector.size());
+
+            // Copy all DOFs for this joint
+            for (size_t i = 0; i < jnt->getNrOfDOFs(); i++)
+            {
+                fullVector(jntInFullModel->getDOFsOffset() + i) = reducedVector(jnt->getDOFsOffset() + i);
+            }
         }
     }
 }
@@ -183,7 +261,39 @@ void copyFromFullToReduced(      vectorType & reducedVector,
         {
             IJointConstPtr jntInFullModel = fullModel.getJoint(fullModel.getJointIndex(jointName));
 
-            reducedVector(jnt->getPosCoordsOffset()) = fullVector(jntInFullModel->getPosCoordsOffset());
+            // Copy all position coordinates for this joint
+            for (size_t i = 0; i < jnt->getNrOfPosCoords(); i++)
+            {
+                reducedVector(jnt->getPosCoordsOffset() + i) = fullVector(jntInFullModel->getPosCoordsOffset() + i);
+            }
+        }
+    }
+}
+
+/**
+ * Copy a vector of DOFs from the full model to the reduced model.
+ * This function should be used for joint torques, velocities, and accelerations.
+ */
+template<typename vectorType>
+void copyFromFullToReducedDOFs(      vectorType & reducedVector,
+                      const vectorType & fullVector,
+                      const Model & reducedModel,
+                      const Model & fullModel)
+{
+    for(JointIndex jntReduced = 0; jntReduced < reducedModel.getNrOfJoints(); jntReduced++ )
+    {
+        IJointConstPtr jnt = reducedModel.getJoint(jntReduced);
+        std::string jointName = reducedModel.getJointName(jntReduced);
+
+        if( jnt->getNrOfDOFs() > 0 )
+        {
+            IJointConstPtr jntInFullModel = fullModel.getJoint(fullModel.getJointIndex(jointName));
+
+            // Copy all DOFs for this joint
+            for (size_t i = 0; i < jnt->getNrOfDOFs(); i++)
+            {
+                reducedVector(jnt->getDOFsOffset() + i) = fullVector(jntInFullModel->getDOFsOffset() + i);
+            }
         }
     }
 }
@@ -200,11 +310,17 @@ void checkReducedModel(const Model & model)
     // is giving the same results
     for(size_t jnts=0; jnts < model.getNrOfJoints(); jnts += 5)
     {
+        FreeFloatingPos fullPos(model);
+
         std::vector<std::string> jointInReducedModel;
         getRandomSubsetOfJoints(model,jnts,jointInReducedModel);
 
+        // Get random positions for reduced models
+        std::unordered_map<std::string, std::vector<double>> removedJointPositions;
+        getRandomJointPositionsForJointsNotInReducedModels(model, jointInReducedModel, removedJointPositions, fullPos);
+
         Model reducedModel;
-        bool ok = createReducedModel(model,jointInReducedModel,reducedModel);
+        bool ok = createReducedModel(model, jointInReducedModel, reducedModel, removedJointPositions);
 
         ASSERT_EQUAL_DOUBLE(ok,1.0);
 
@@ -224,7 +340,7 @@ void checkReducedModel(const Model & model)
         FreeFloatingGeneralizedTorques reducedTrqsCheck(reducedModel);
 
         reducedPos.worldBasePos() = getRandomTransform();
-        getRandomVector(reducedPos.jointPos());
+        getRandomJointPositions(reducedPos.jointPos(), reducedModel);
 
         reducedVel.baseVel() = getRandomTwist();
         getRandomVector(reducedVel.jointVel());
@@ -232,7 +348,6 @@ void checkReducedModel(const Model & model)
         reducedAcc.baseAcc() = getRandomTwist();
         getRandomVector(reducedAcc.jointAcc());
 
-        FreeFloatingPos fullPos(model);
         FreeFloatingVel fullVel(model);
         FreeFloatingAcc fullAcc(model);
         FreeFloatingGeneralizedTorques fullTrqs(model);
@@ -242,14 +357,34 @@ void checkReducedModel(const Model & model)
         fullAcc.baseAcc()      = reducedAcc.baseAcc();
 
         copyFromReducedToFull(reducedPos.jointPos(),fullPos.jointPos(),reducedModel,model);
-        copyFromReducedToFull(reducedVel.jointVel(),fullVel.jointVel(),reducedModel,model);
-        copyFromReducedToFull(reducedAcc.jointAcc(),fullAcc.jointAcc(),reducedModel,model);
+        copyFromReducedToFullDOFs(reducedVel.jointVel(),fullVel.jointVel(),reducedModel,model);
+        copyFromReducedToFullDOFs(reducedAcc.jointAcc(),fullAcc.jointAcc(),reducedModel,model);
 
         fullRNEA.runRNEA(fullPos,fullVel,fullAcc,fullTrqs);
         reducedRNEA.runRNEA(reducedPos,reducedVel,reducedAcc,reducedTrqs);
 
+        // Test if the velocity of the two RNEAs are the same, accounting for the different link serialization
+        // Compare link-by-link using names to map indices between models
+        for (LinkIndex redLinkIdx = 0; redLinkIdx < static_cast<LinkIndex>(reducedModel.getNrOfLinks()); ++redLinkIdx)
+        {
+            std::string linkName = reducedModel.getLinkName(redLinkIdx);
+            std::cerr << "Comparing link " << linkName << " of reduced model ( " << redLinkIdx << " ) " << std::endl;
+            LinkIndex fullLinkIdx = model.getLinkIndex(linkName);
+            ASSERT_IS_TRUE(fullLinkIdx != LINK_INVALID_INDEX);
+
+            // Velocities
+            ASSERT_EQUAL_VECTOR_TOL(reducedRNEA.linkVels(redLinkIdx).asVector(),
+                                    fullRNEA.linkVels(fullLinkIdx).asVector(),
+                                    1e-8);
+
+            // Accelerations
+            ASSERT_EQUAL_VECTOR_TOL(reducedRNEA.linkAccs(redLinkIdx).asVector(),
+                                    fullRNEA.linkAccs(fullLinkIdx).asVector(),
+                                    1e-8);
+        }
+
         reducedTrqsCheck.baseWrench() = fullTrqs.baseWrench();
-        copyFromFullToReduced(reducedTrqsCheck.jointTorques(),fullTrqs.jointTorques(),reducedModel,model);
+        copyFromFullToReducedDOFs(reducedTrqsCheck.jointTorques(),fullTrqs.jointTorques(),reducedModel,model);
 
         ASSERT_EQUAL_VECTOR_TOL(reducedTrqs.baseWrench().asVector(),reducedTrqsCheck.baseWrench().asVector(),1e-8);
         ASSERT_EQUAL_VECTOR_TOL(reducedTrqs.jointTorques(),reducedTrqsCheck.jointTorques(),1e-8);
@@ -257,11 +392,51 @@ void checkReducedModel(const Model & model)
 
 }
 
+void checkExtractSubModel(const Model & model)
+{
+    for(size_t jnts=1; jnts < model.getNrOfJoints(); jnts += 5)
+    {
+
+        Traversal traversal;
+        bool ok = model.computeFullTreeTraversal(traversal);
+
+        ASSERT_EQUAL_DOUBLE(ok,true);
+
+        std::vector<std::string> jointInReducedModel;
+        getRandomSubsetOfJoints(model,jnts,jointInReducedModel);
+
+        iDynTree::SubModelDecomposition subModels;
+        ok = subModels.splitModelAlongJoints(model,traversal,jointInReducedModel);
+
+        ASSERT_EQUAL_DOUBLE(ok,true);
+
+        for(int subModelIdx = 0; subModelIdx < subModels.getNrOfSubModels(); subModelIdx++)
+        {
+            const Traversal & subModelTraversal = subModels.getTraversal(subModelIdx);
+
+            Model reducedModel;
+            ok = extractSubModel(model, subModelTraversal, reducedModel);
+
+            ASSERT_EQUAL_DOUBLE(ok,true);
+
+            for (int linkIdx = 0; linkIdx < subModelTraversal.getNrOfVisitedLinks(); linkIdx++)
+            {
+                auto linkSubModel = subModelTraversal.getLink(linkIdx);
+                auto linkModel = model.getLink(model.getLinkIndex(reducedModel.getLinkName(linkIdx)));
+
+                ASSERT_EQUAL_MATRIX(linkSubModel->getInertia().asMatrix(), linkModel->getInertia().asMatrix());
+            }
+        }
+    }
+}
+
 void checkAll(const Model & model)
 {
     createCopyAndDestroy(model);
     checkNeighborSanity(model,false);
     checkComputeTraversal(model);
+    checkReducedModel(model);
+    checkExtractSubModel(model);
 }
 
 void checkSimpleModel()
@@ -272,7 +447,7 @@ void checkSimpleModel()
                                   0.0,12.0,0.0,
                                   0.0,0.0,10.0};
 
-    SpatialInertia inertiaLink0(1.0,Position(100,0,0),RotationalInertiaRaw(rotInertiaData,3,3));
+    SpatialInertia inertiaLink0(1.0,Position(100,0,0),RotationalInertia(rotInertiaData,3,3));
 
     Link link0;
     link0.setInertia(inertiaLink0);
@@ -321,7 +496,7 @@ void checkInsertJointAndLink()
                                   0.0,12.0,0.0,
                                   0.0,0.0,10.0};
 
-    SpatialInertia inertiaLink0(1.0,Position(100,0,0),RotationalInertiaRaw(rotInertiaData,3,3));
+    SpatialInertia inertiaLink0(1.0,Position(100,0,0),RotationalInertia(rotInertiaData,3,3));
 
     Link link0;
     link0.setInertia(inertiaLink0);
@@ -386,7 +561,7 @@ void checkRandomModels()
 
     for(int i=2; i <= 100; i += 30 )
     {
-        Model randomModel = getRandomModel(i);
+        Model randomModel = getRandomModel(i,/*nrOfAdditionalFrames =*/10, SIMPLE_JOINT_TYPES | JOINT_REVOLUTE_SO2 | JOINT_SPHERICAL);
 
         std::cout << "Checking reduced model for random model of size: " << i << std::endl;
         checkAll(randomModel);
