@@ -1,35 +1,27 @@
-/*
- * Copyright (C) 2018 Fondazione Istituto Italiano di Tecnologia
- *
- * Author: Francesco Romano - Google LLC
- *
- * Licensed under either the GNU Lesser General Public License v3.0 :
- * https://www.gnu.org/licenses/lgpl-3.0.html
- * or the GNU Lesser General Public License v2.1 :
- * https://www.gnu.org/licenses/old-licenses/lgpl-2.1.html
- * at your option.
- */
+// SPDX-FileCopyrightText: Fondazione Istituto Italiano di Tecnologia (IIT)
+// SPDX-License-Identifier: BSD-3-Clause
 
 #ifndef IDYNTREE_MODELIO_URDF_INERTIAELEMENT_H
 #define IDYNTREE_MODELIO_URDF_INERTIAELEMENT_H
 
 #include <iDynTree/XMLElement.h>
 
-#include <iDynTree/Core/Transform.h>
-#include <iDynTree/Model/Model.h>
+#include <iDynTree/Transform.h>
+#include <iDynTree/Model.h>
 
 namespace iDynTree {
     class InertialElement;
+    class XMLParserState;
 }
 
 class iDynTree::InertialElement: public iDynTree::XMLElement {
     Transform m_centerOfMass;
     double m_mass;
-    RotationalInertiaRaw m_rotationalInertiaWRTCoM;
+    RotationalInertia m_rotationalInertiaWRTCoM;
     iDynTree::Link &m_link;
     
 public:
-    InertialElement(iDynTree::Link &link);
+    explicit InertialElement(XMLParserState& parserState, iDynTree::Link &link);
     
     std::shared_ptr<iDynTree::XMLElement> childElementForName(const std::string& name) override;
     
