@@ -1,14 +1,5 @@
-/*
- * Copyright (C) 2018 Fondazione Istituto Italiano di Tecnologia
- *
- * Author: Francesco Romano - Google LLC
- *
- * Licensed under either the GNU Lesser General Public License v3.0 :
- * https://www.gnu.org/licenses/lgpl-3.0.html
- * or the GNU Lesser General Public License v2.1 :
- * https://www.gnu.org/licenses/old-licenses/lgpl-2.1.html
- * at your option.
- */
+// SPDX-FileCopyrightText: Fondazione Istituto Italiano di Tecnologia (IIT)
+// SPDX-License-Identifier: BSD-3-Clause
 
 #ifndef IDYNTREE_MODELIO_URDF_LINKELEMENT_H
 #define IDYNTREE_MODELIO_URDF_LINKELEMENT_H
@@ -17,13 +8,14 @@
 
 #include "VisualElement.h"
 
-#include <iDynTree/Model/Link.h>
+#include <iDynTree/Link.h>
 
 namespace iDynTree {
     class LinkElement;
     class XMLAttribute;
     
     class Model;
+    class XMLParserState;
 }
 
 class iDynTree::LinkElement : public iDynTree::XMLElement {
@@ -35,7 +27,7 @@ class iDynTree::LinkElement : public iDynTree::XMLElement {
     std::vector<VisualElement::VisualInfo> m_collisions;
     
 public:
-    LinkElement(iDynTree::Model &model);
+    explicit LinkElement(XMLParserState& parserState, iDynTree::Model &model);
 
     // Exposing useful properties
     const std::string& linkName() const;
