@@ -1,21 +1,12 @@
-/*
- * Copyright (C) 2018 Fondazione Istituto Italiano di Tecnologia
- *
- * Author: Francesco Romano - Google LLC
- *
- * Licensed under either the GNU Lesser General Public License v3.0 :
- * https://www.gnu.org/licenses/lgpl-3.0.html
- * or the GNU Lesser General Public License v2.1 :
- * https://www.gnu.org/licenses/old-licenses/lgpl-2.1.html
- * at your option.
- */
+// SPDX-FileCopyrightText: Fondazione Istituto Italiano di Tecnologia (IIT)
+// SPDX-License-Identifier: BSD-3-Clause
 
 #ifndef IDYNTREE_MODELIO_URDF_MATERIALELEMENT_H
 #define IDYNTREE_MODELIO_URDF_MATERIALELEMENT_H
 
 #include <iDynTree/XMLElement.h>
 
-#include <iDynTree/Core/VectorFixSize.h>
+#include <iDynTree/VectorFixSize.h>
 
 #include <memory>
 #include <string>
@@ -25,6 +16,7 @@ namespace iDynTree {
     class MaterialElement;
 
     class XMLAttribute;
+    class XMLParserState;
 }
 
 class iDynTree::MaterialElement: public iDynTree::XMLElement
@@ -40,8 +32,10 @@ private:
     std::shared_ptr<MaterialInfo> m_info;
 
 public:
+    explicit MaterialElement(
+        XMLParserState& parserState, 
+        std::shared_ptr<MaterialInfo> materialInfo);
 
-    MaterialElement(std::shared_ptr<MaterialInfo> materialInfo);
     const std::shared_ptr<MaterialInfo> materialInfo() const;
 
     bool setAttributes(const std::unordered_map<std::string, std::shared_ptr<iDynTree::XMLAttribute>>& attributes) override;
