@@ -1,18 +1,11 @@
-/*
- * Copyright (C) 2015 Fondazione Istituto Italiano di Tecnologia
- *
- * Licensed under either the GNU Lesser General Public License v3.0 :
- * https://www.gnu.org/licenses/lgpl-3.0.html
- * or the GNU Lesser General Public License v2.1 :
- * https://www.gnu.org/licenses/old-licenses/lgpl-2.1.html
- * at your option.
- */
+// SPDX-FileCopyrightText: Fondazione Istituto Italiano di Tecnologia (IIT)
+// SPDX-License-Identifier: BSD-3-Clause
 
-#include "iDynTree/ModelIO/URDFDofsImport.h"
+#include "iDynTree/URDFDofsImport.h"
 
-#include "iDynTree/ModelIO/ModelLoader.h"
+#include "iDynTree/ModelLoader.h"
 
-#include <iDynTree/Model/Model.h>
+#include <iDynTree/Model.h>
 
 #include <cstdlib>
 #include <cmath>
