@@ -1,21 +1,22 @@
-/*
- * Copyright (C) 2017 Fondazione Istituto Italiano di Tecnologia
- * Authors: Silvio Traversaro
- * CopyPolicy: Released under the terms of the LGPLv2.1 or later, see LGPL.TXT
- */
+// SPDX-FileCopyrightText: Fondazione Istituto Italiano di Tecnologia (IIT)
+// SPDX-License-Identifier: BSD-3-Clause
+
 
 #include "URDFModelExport.h"
 
-#include <iDynTree/Core/EigenHelpers.h>
-#include <iDynTree/Core/SpatialInertia.h>
-#include <iDynTree/Core/Transform.h>
-#include <iDynTree/Core/VectorFixSize.h>
-#include <iDynTree/Model/FixedJoint.h>
-#include <iDynTree/Model/Indices.h>
-#include <iDynTree/Model/Model.h>
-#include <iDynTree/Model/PrismaticJoint.h>
-#include <iDynTree/Model/RevoluteJoint.h>
-#include <iDynTree/Model/Traversal.h>
+#include <iDynTree/EigenHelpers.h>
+#include <iDynTree/SpatialInertia.h>
+#include <iDynTree/Transform.h>
+#include <iDynTree/VectorFixSize.h>
+#include <iDynTree/FixedJoint.h>
+#include <iDynTree/Indices.h>
+#include <iDynTree/Model.h>
+#include <iDynTree/PrismaticJoint.h>
+#include <iDynTree/RevoluteJoint.h>
+#include <iDynTree/Traversal.h>
+#include <iDynTree/Axis.h>
+#include <iDynTree/SphericalJoint.h>
+#include <iDynTree/ModelTransformers.h>
 
 #include "URDFParsingUtils.h"
 
@@ -31,6 +32,7 @@
 namespace iDynTree
 {
 
+
 /*
  * This file uses extensivly the libxml2's tree API, see
  * http://www.xmlsoft.org/examples/index.html#Tree for more info.
@@ -91,7 +93,7 @@ bool exportInertial(const SpatialInertia &inertia, xmlNodePtr parent_element)
     ok = ok && exportTransform(Transform(Rotation::Identity(), inertia.getCenterOfMass()), inertial);
 
     xmlNodePtr inertia_xml = xmlNewChild(inertial, NULL, BAD_CAST "inertia", NULL);
-    RotationalInertiaRaw rotInertia = inertia.getRotationalInertiaWrtCenterOfMass();
+    RotationalInertia rotInertia = inertia.getRotationalInertiaWrtCenterOfMass();
     ok = ok && doubleToStringWithClassicLocale(rotInertia(0, 0), bufStr);
     xmlNewProp(inertia_xml, BAD_CAST "ixx", BAD_CAST bufStr.c_str());
     ok = ok && doubleToStringWithClassicLocale(rotInertia(0, 1), bufStr);
@@ -285,7 +287,7 @@ bool exportLink(const Link &link, const std::string linkName, const Model& model
  * Add a <joint> URDF element to the specified parent element with the specified joint info.
  *
  * At the moment, only the URDF joint of types revolute, continuous, prismatic and fixed are supported, as they are the only one supported
- * in the iDynTree::Model class. Furthermore, it is not supported the export of joint limits and friction.
+ * in the iDynTree::Model class.
  *
  * If parent_element contains a pointer to a tag <parent_element></parent_element>, this function modifies it to be something like:
  *
@@ -327,6 +329,12 @@ bool exportJoint(IJointConstPtr joint, LinkConstPtr parentLink, LinkConstPtr chi
     {
         xmlNewProp(joint_xml, BAD_CAST "type", BAD_CAST "prismatic");
     }
+    else if (dynamic_cast<const SphericalJoint*>(joint))
+    {
+        std::cerr << "[ERROR] URDFModelExport: Impossible to convert joint of type SphericalJoint to a URDF joint (spherical joints are not supported in URDF)."
+                  << " For exporting joint of type SphericalJoint, ensure that the  ModelExporterOptions::SphericalJointsAsThreeRevoluteJoints parameter is set to true." << std::endl;
+        return false;
+    }
     else
     {
         std::cerr << "[ERROR] URDFModelExport: Impossible to convert joint of type "
@@ -359,13 +367,16 @@ bool exportJoint(IJointConstPtr joint, LinkConstPtr parentLink, LinkConstPtr chi
             return false;
         }
 
-        // Check that the axis is URDF-compatible
-        if (toEigen(axis.getOrigin()).norm() > 1e-7)
+        // Check that the axis is URDF-compatible, i.e. that the distance between the
+        // axis and the child link origin is zero
+        double distanceBetweenAxisAndOrigin = axis.getDistanceBetweenAxisAndPoint(iDynTree::Position::Zero());
+        if (distanceBetweenAxisAndOrigin > 1e-7)
         {
             std::cerr << "[ERROR] URDFModelExport: Impossible to convert joint "
                       <<   model.getJointName(joint->getIndex()) << " to a URDF joint without moving the link frame of link "
-                      << model.getLinkName(childLink->getIndex()) << " , because its origin is "
-                      << axis.getOrigin().toString()  << std::endl;
+                      << model.getLinkName(childLink->getIndex()) << " , because the axis origin is "
+                      << axis.getOrigin().toString() << " the axis direction is " << axis.getDirection().toString()
+                      << " and the distance between the axis and (0,0,0) is " << distanceBetweenAxisAndOrigin << std::endl;
             return false;
         }
 
@@ -385,12 +396,24 @@ bool exportJoint(IJointConstPtr joint, LinkConstPtr parentLink, LinkConstPtr chi
     xmlNewProp(child_xml, BAD_CAST "link", BAD_CAST model.getLinkName(childLink->getIndex()).c_str());
 
     // Position limits
-    if (joint->hasPosLimits() && joint->getNrOfDOFs() == 1)
+    // Limits are required for prismatic joints even if no limits are enabled, see URDF spec for reference
+    bool isJointPrismatic = dynamic_cast<const PrismaticJoint*>(joint);
+    if ( (joint->hasPosLimits() && joint->getNrOfDOFs() == 1) || isJointPrismatic)
     {
         xmlNodePtr limit_xml = xmlNewChild(joint_xml, NULL, BAD_CAST "limit", NULL);
         std::string bufStr;
         double min, max;
-        ok = ok && joint->getPosLimits(0, min, max);
+        double reallyHighLimit = 1e9;
+
+        // If joint is prismatic and has no limits, we just put really high values as limits are required
+        if (isJointPrismatic && !joint->hasPosLimits())
+        {
+            min = -reallyHighLimit;
+            max = +reallyHighLimit;
+        } else
+        {
+            ok = ok && joint->getPosLimits(0, min, max);
+        }
 
         ok = ok && doubleToStringWithClassicLocale(min, bufStr);
         xmlNewProp(limit_xml, BAD_CAST "lower", BAD_CAST bufStr.c_str());
@@ -398,14 +421,24 @@ bool exportJoint(IJointConstPtr joint, LinkConstPtr parentLink, LinkConstPtr chi
         xmlNewProp(limit_xml, BAD_CAST "upper", BAD_CAST bufStr.c_str());
 
         // Workaround for https://github.com/robotology/idyntree/issues/955
-        double reallyHighLimit = 1e9;
         ok = ok && doubleToStringWithClassicLocale(reallyHighLimit, bufStr);
         xmlNewProp(limit_xml, BAD_CAST "effort", BAD_CAST bufStr.c_str());
         ok = ok && doubleToStringWithClassicLocale(reallyHighLimit, bufStr);
         xmlNewProp(limit_xml, BAD_CAST "velocity", BAD_CAST bufStr.c_str());
     }
 
-    // TODO(traversaro) : handle friction
+    if (joint->getJointDynamicsType() == URDFJointDynamics && joint->getNrOfDOFs() == 1)
+    {
+        xmlNodePtr dynamics_xml = xmlNewChild(joint_xml, NULL, BAD_CAST "dynamics", NULL);
+        std::string bufStr;
+        double damping = 0.0, static_friction = 0.0;
+        damping = joint->getDamping(0);
+        static_friction = joint->getStaticFriction(0);
+        ok = ok && doubleToStringWithClassicLocale(damping, bufStr);
+        xmlNewProp(dynamics_xml, BAD_CAST "damping", BAD_CAST bufStr.c_str());
+        ok = ok && doubleToStringWithClassicLocale(static_friction, bufStr);
+        xmlNewProp(dynamics_xml, BAD_CAST "friction", BAD_CAST bufStr.c_str());
+    }
 
     return ok;
 }
@@ -433,6 +466,19 @@ enum exportAdditionalFrameDirectionOption {
     FAKE_LINK_IS_CHILD,
     FAKE_LINK_IS_PARENT
 };
+bool exportXMLBlob(std::string xmlBlob, xmlNodePtr parent_element) {
+     xmlNodePtr new_node = nullptr;
+     // Let's remove non printable characters
+     xmlBlob.erase(std::remove_if(xmlBlob.begin(), xmlBlob.end(),
+         [](unsigned char c) {
+             return !std::isprint(c);
+         }),
+         xmlBlob.end());
+    // we assume that 'parent_element' node is already defined
+    xmlParseInNodeContext(parent_element, xmlBlob.c_str(), strlen(xmlBlob.c_str()), 0, &new_node);
+    if (new_node) xmlAddChild(parent_element, new_node);
+    return true;
+}
 bool exportAdditionalFrame(const std::string frame_name, Transform link_H_frame, const std::string link_name, exportAdditionalFrameDirectionOption direction_option, xmlNodePtr parent_element)
 {
     bool ok=true;
@@ -479,8 +525,20 @@ bool URDFStringFromModel(const iDynTree::Model & model,
                          std::string & urdf_string,
                          const ModelExporterOptions options)
 {
-    bool ok = true;
+    Model processedModel;
+    // Convert spherical joints if option is enabled
+    if (options.exportSphericalJointsAsThreeRevoluteJoints) {
+        if (!convertSphericalJointsToThreeRevoluteJoints(model, processedModel,
+                                                         options.sphericalJointFakeLinkPrefix,
+                                                         options.sphericalJointRevoluteJointPrefix)) {
+            std::cerr << "[ERROR] URDFStringFromModel: Failed to convert spherical joints for URDF export" << std::endl;
+            return false;
+        }
+    } else {
+        processedModel = model;
+    }
 
+    bool ok = true;
     xmlDocPtr urdf_xml = xmlNewDoc(BAD_CAST "1.0");
     xmlNodePtr robot = xmlNewNode(NULL, BAD_CAST "robot");
     // TODO(traversaro) properly export this :)
@@ -495,10 +553,10 @@ bool URDFStringFromModel(const iDynTree::Model & model,
     std::string baseLink = options.baseLink;
     if (baseLink.empty())
     {
-        baseLink = model.getLinkName(model.getDefaultBaseLink());
+        baseLink = processedModel.getLinkName(processedModel.getDefaultBaseLink());
     }
 
-    LinkIndex baseLinkIndex = model.getLinkIndex(baseLink);
+    LinkIndex baseLinkIndex = processedModel.getLinkIndex(baseLink);
     if (baseLinkIndex == LINK_INVALID_INDEX)
     {
         std::cerr << "[ERROR] URDFStringFromModel : specified baseLink " << baseLink << " is not part of the model" << std::endl;
@@ -518,9 +576,9 @@ bool URDFStringFromModel(const iDynTree::Model & model,
     ok = model.getLinkAdditionalFrames(baseLinkIndex, frameIndices);
     if (ok && frameIndices.size() >= 1 && options.exportFirstBaseLinkAdditionalFrameAsFakeURDFBase) {
         baseFakeLinkFrameIndex = frameIndices[0];
-        ok = ok && exportAdditionalFrame(model.getFrameName(baseFakeLinkFrameIndex),
-                                         model.getFrameTransform(baseFakeLinkFrameIndex),
-                                         model.getLinkName(model.getFrameLink(baseFakeLinkFrameIndex)),
+        ok = ok && exportAdditionalFrame(processedModel.getFrameName(baseFakeLinkFrameIndex),
+                                         processedModel.getFrameTransform(baseFakeLinkFrameIndex),
+                                         processedModel.getLinkName(processedModel.getFrameLink(baseFakeLinkFrameIndex)),
                                          FAKE_LINK_IS_PARENT,
                                          robot);
     }
@@ -528,48 +586,49 @@ bool URDFStringFromModel(const iDynTree::Model & model,
 
     // Create a Traversal
     Traversal exportTraversal;
-    if (!model.computeFullTreeTraversal(exportTraversal, baseLinkIndex))
+    if (!processedModel.computeFullTreeTraversal(exportTraversal, baseLinkIndex))
     {
         std::cerr << "[ERROR] URDFStringFromModel : error in computeFullTreeTraversal" << std::endl;
         xmlFreeDoc(urdf_xml);
         return false;
     }
 
-
     // Export links and joints following the traversal
     for (TraversalIndex trvIdx=0; trvIdx < static_cast<TraversalIndex>(exportTraversal.getNrOfVisitedLinks()); trvIdx++)
     {
         LinkConstPtr visitedLink = exportTraversal.getLink(trvIdx);
-        std::string visitedLinkName = model.getLinkName(visitedLink->getIndex());
+        std::string visitedLinkName = processedModel.getLinkName(visitedLink->getIndex());
 
         // Export parent joint, if this is not the base
         if (trvIdx != 0)
         {
             LinkConstPtr parentLink = exportTraversal.getParentLink(trvIdx);
             IJointConstPtr parentJoint = exportTraversal.getParentJoint(trvIdx);
-            ok = ok && exportJoint(parentJoint, parentLink, visitedLink,  model, robot);
+            ok = ok && exportJoint(parentJoint, parentLink, visitedLink,  processedModel, robot);
         }
 
         // Export link
-        ok = ok && exportLink(*visitedLink, visitedLinkName, model, robot);
+        ok = ok && exportLink(*visitedLink, visitedLinkName, processedModel, robot);
     }
 
     // Export all the additional frames.
-    for (FrameIndex frameIndex=model.getNrOfLinks(); frameIndex < static_cast<FrameIndex>(model.getNrOfFrames()); frameIndex++)
+    for (FrameIndex frameIndex=processedModel.getNrOfLinks(); frameIndex < static_cast<FrameIndex>(processedModel.getNrOfFrames()); frameIndex++)
     {
         // Check that the frame is not parent of the base link and that the
         // frame link is present in the traversal.
         if (frameIndex != baseFakeLinkFrameIndex
-            && exportTraversal.getTraversalIndexFromLinkIndex(model.getFrameLink(frameIndex)) != TRAVERSAL_INVALID_INDEX) {
+            && exportTraversal.getTraversalIndexFromLinkIndex(processedModel.getFrameLink(frameIndex)) != TRAVERSAL_INVALID_INDEX) {
 
-            ok = ok && exportAdditionalFrame(model.getFrameName(frameIndex),
-                                             model.getFrameTransform(frameIndex),
-                                             model.getLinkName(model.getFrameLink(frameIndex)),
+            ok = ok && exportAdditionalFrame(processedModel.getFrameName(frameIndex),
+                                             processedModel.getFrameTransform(frameIndex),
+                                             processedModel.getLinkName(processedModel.getFrameLink(frameIndex)),
                                              FAKE_LINK_IS_CHILD,
                                              robot);
         }
     }
-
+    for (auto& xmlBlob : options.xmlBlobs) {
+        ok = ok && exportXMLBlob(xmlBlob, robot);
+    }
     xmlChar *xmlbuff=0;
     int buffersize=0;
     xmlDocDumpFormatMemory(urdf_xml, &xmlbuff, &buffersize, 1);
@@ -599,6 +658,7 @@ bool URDFFromModel(const iDynTree::Model & model,
     std::string xml_string;
     if (!URDFStringFromModel(model, xml_string, options))
     {
+        std::cerr << "[ERROR] URDFFromModel: Failed to generate URDF string from processed model" << std::endl;
         return false;
     }
 
@@ -609,5 +669,4 @@ bool URDFFromModel(const iDynTree::Model & model,
     return true;
 }
 
-
 }
