@@ -1,14 +1,5 @@
-/*
- * Copyright (C) 2018 Fondazione Istituto Italiano di Tecnologia
- *
- * Author: Francesco Romano - Google LLC
- *
- * Licensed under either the GNU Lesser General Public License v3.0 :
- * https://www.gnu.org/licenses/lgpl-3.0.html
- * or the GNU Lesser General Public License v2.1 :
- * https://www.gnu.org/licenses/old-licenses/lgpl-2.1.html
- * at your option.
- */
+// SPDX-FileCopyrightText: Fondazione Istituto Italiano di Tecnologia (IIT)
+// SPDX-License-Identifier: BSD-3-Clause
 
 #include "XMLDocument.h"
 
@@ -22,10 +13,14 @@ namespace iDynTree {
     {
     public:
         std::shared_ptr<XMLElement> m_root;
+        XMLParserState& m_parserState;
+
+        explicit XMLDocumentPimpl(XMLParserState& parserState)
+        : m_parserState(parserState) {}
     };
     
-    XMLDocument::XMLDocument()
-    : m_pimpl(new XMLDocumentPimpl()) {}
+    XMLDocument::XMLDocument(XMLParserState& parserState)
+    : m_pimpl(new XMLDocumentPimpl(parserState)) {}
     
     XMLDocument::~XMLDocument() {}
     
@@ -39,9 +34,10 @@ namespace iDynTree {
         return m_pimpl->m_root;
     }
     
-    std::shared_ptr<XMLElement> XMLDocument::rootElementForName(const std::string& name)
+    std::shared_ptr<XMLElement> XMLDocument::rootElementForName(const std::string& name,
+                                                                const std::vector<std::string>& packageDirs)
     {
-        return std::make_shared<XMLElement>(name);
+        return std::make_shared<XMLElement>(m_pimpl->m_parserState, name);
     }
 
     bool XMLDocument::documentHasBeenParsed() { return true; }
@@ -54,4 +50,6 @@ namespace iDynTree {
         }
         return str.str();
     }
+
+    XMLParserState& XMLDocument::getParserState() { return m_pimpl->m_parserState; }
 }
