@@ -1,12 +1,6 @@
+// SPDX-FileCopyrightText: Fondazione Istituto Italiano di Tecnologia (IIT)
+// SPDX-License-Identifier: BSD-3-Clause
 /*
- * Copyright (C) 2014,2018 Fondazione Istituto Italiano di Tecnologia
- *
- * Licensed under either the GNU Lesser General Public License v3.0 :
- * https://www.gnu.org/licenses/lgpl-3.0.html
- * or the GNU Lesser General Public License v2.1 :
- * https://www.gnu.org/licenses/old-licenses/lgpl-2.1.html
- * at your option.
- *
  * Originally developed for Prioritized Optimal Control (2014)
  * Refactored in 2018.
  * Design inspired by
@@ -15,10 +9,10 @@
  */
 
 #include <iDynTree/QuadraticLikeCost.h>
-#include <iDynTree/Core/Utils.h>
+#include <iDynTree/Utils.h>
 
 #include <Eigen/Dense>
-#include <iDynTree/Core/EigenHelpers.h>
+#include <iDynTree/EigenHelpers.h>
 #include <cmath>
 
 namespace iDynTree {
