@@ -1,12 +1,6 @@
+// SPDX-FileCopyrightText: Fondazione Istituto Italiano di Tecnologia (IIT)
+// SPDX-License-Identifier: BSD-3-Clause
 /*
- * Copyright (C) 2014,2018 Fondazione Istituto Italiano di Tecnologia
- *
- * Licensed under either the GNU Lesser General Public License v3.0 :
- * https://www.gnu.org/licenses/lgpl-3.0.html
- * or the GNU Lesser General Public License v2.1 :
- * https://www.gnu.org/licenses/old-licenses/lgpl-2.1.html
- * at your option.
- *
  * Originally developed for Prioritized Optimal Control (2014)
  * Refactored in 2018.
  * Design inspired by
@@ -22,14 +16,14 @@
 #include <iDynTree/Optimizer.h>
 #include <iDynTree/OCSolvers/MultipleShootingSolver.h>
 #include <iDynTree/DynamicalSystem.h>
-#include <iDynTree/Core/TestUtils.h>
-#include <iDynTree/Core/Utils.h>
+#include <iDynTree/TestUtils.h>
+#include <iDynTree/Utils.h>
 #include <iDynTree/Integrators/ForwardEuler.h>
-#include <iDynTree/Core/VectorDynSize.h>
-#include <iDynTree/Core/MatrixDynSize.h>
+#include <iDynTree/VectorDynSize.h>
+#include <iDynTree/MatrixDynSize.h>
 #include <iDynTree/TimeRange.h>
 #include <Eigen/Dense>
-#include <iDynTree/Core/EigenHelpers.h>
+#include <iDynTree/EigenHelpers.h>
 #include <string>
 
 class TestSystem : public iDynTree::optimalcontrol::DynamicalSystem {
