@@ -1,32 +1,25 @@
-/*
- * Copyright (C) 2015 Fondazione Istituto Italiano di Tecnologia
- *
- * Licensed under either the GNU Lesser General Public License v3.0 :
- * https://www.gnu.org/licenses/lgpl-3.0.html
- * or the GNU Lesser General Public License v2.1 :
- * https://www.gnu.org/licenses/old-licenses/lgpl-2.1.html
- * at your option.
- */
+// SPDX-FileCopyrightText: Fondazione Istituto Italiano di Tecnologia (IIT)
+// SPDX-License-Identifier: BSD-3-Clause
 
 
-#include <iDynTree/Core/TestUtils.h>
-#include <iDynTree/Core/EigenHelpers.h>
+#include <iDynTree/TestUtils.h>
+#include <iDynTree/EigenHelpers.h>
 
-#include <iDynTree/Model/Model.h>
-#include <iDynTree/Model/Traversal.h>
+#include <iDynTree/Model.h>
+#include <iDynTree/Traversal.h>
 
-#include <iDynTree/Model/ForwardKinematics.h>
-#include <iDynTree/Model/Dynamics.h>
-#include <iDynTree/Model/DynamicsLinearization.h>
+#include <iDynTree/ForwardKinematics.h>
+#include <iDynTree/Dynamics.h>
+#include <iDynTree/DynamicsLinearization.h>
 
-#include <iDynTree/Model/JointState.h>
-#include <iDynTree/Model/LinkState.h>
-#include <iDynTree/Model/FreeFloatingState.h>
-#include <iDynTree/Model/FreeFloatingMatrices.h>
+#include <iDynTree/JointState.h>
+#include <iDynTree/LinkState.h>
+#include <iDynTree/FreeFloatingState.h>
+#include <iDynTree/FreeFloatingMatrices.h>
 
-#include <iDynTree/Model/ModelTestUtils.h>
+#include <iDynTree/ModelTestUtils.h>
 
-#include <iDynTree/ModelIO/ModelLoader.h>
+#include <iDynTree/ModelLoader.h>
 
 #include "testModels.h"
 
@@ -479,7 +472,7 @@ int main()
     // First test some models used for debug
     Model doubleBodyModel;
 
-    RotationalInertiaRaw rotInertia = RotationalInertiaRaw::Zero();
+    RotationalInertia rotInertia = RotationalInertia::Zero();
     rotInertia(0,0) = rotInertia(1,1) = rotInertia(2,2) = 1.0;
 
     Position com = Position::Zero();
@@ -512,8 +505,6 @@ int main()
     std::cerr << "Checking DynamicsLinearization test on a point mass model" << std::endl;
     checkABAandABALinearizationAreConsistent(doubleBodyModel);
 
-    return 0;
-
     // Then test random generated chains
     for(unsigned int joints =0; joints < 20; joints++)
     {
@@ -526,7 +517,7 @@ int main()
     for(unsigned int joints =0; joints < 20; joints++)
     {
         std::cerr << "Checking DynamicsLinearization test on on random tree with " << joints  << "joints " << std::endl;
-        Model model = getRandomModel(joints);
+        Model model = getRandomModel(joints, 10, SIMPLE_JOINT_TYPES | JOINT_REVOLUTE_SO2 | JOINT_SPHERICAL);
         checkABAandABALinearizationAreConsistent(model);
     }
 
