@@ -1,12 +1,5 @@
-/*
- * Copyright (C) 2016 Fondazione Istituto Italiano di Tecnologia
- *
- * Licensed under either the GNU Lesser General Public License v3.0 :
- * https://www.gnu.org/licenses/lgpl-3.0.html
- * or the GNU Lesser General Public License v2.1 :
- * https://www.gnu.org/licenses/old-licenses/lgpl-2.1.html
- * at your option.
- */
+// SPDX-FileCopyrightText: Fondazione Istituto Italiano di Tecnologia (IIT)
+// SPDX-License-Identifier: BSD-3-Clause
 
 #include "Camera.h"
 #include "IrrlichtUtils.h"
@@ -51,6 +44,12 @@ void Camera::setAspectRatio(double aspectRatio)
     }
 }
 
+void Camera::setWindowDimensions(unsigned int width, unsigned int height)
+{
+    setAspectRatio(width/ (float)height);
+    m_animator->setWindowDimensions(width, height);
+}
+
 void Camera::setIrrlichtCamera(irr::scene::ICameraSceneNode* cam)
 {
     m_irrCamera = cam;
