@@ -1,20 +1,15 @@
-/*
- * Copyright (C) 2021 Fondazione Istituto Italiano di Tecnologia
- *
- * Licensed under either the GNU Lesser General Public License v3.0 :
- * https://www.gnu.org/licenses/lgpl-3.0.html
- * or the GNU Lesser General Public License v2.1 :
- * https://www.gnu.org/licenses/old-licenses/lgpl-2.1.html
- * at your option.
- */
+// SPDX-FileCopyrightText: Fondazione Istituto Italiano di Tecnologia (IIT)
+// SPDX-License-Identifier: BSD-3-Clause
 #ifndef IDYNTREE_FRAMEVISUALIZATION_H
 #define IDYNTREE_FRAMEVISUALIZATION_H
 
 #include <iDynTree/Visualizer.h>
 #include "Label.h"
+#include "ModelVisualization.h"
 
 #include <vector>
 #include <irrlicht.h>
+#include <memory>
 
 namespace iDynTree
 {
@@ -24,10 +19,13 @@ namespace iDynTree
         {
             irr::scene::ISceneNode * visualizationNode = nullptr;
             Label label;
+            std::string parentModel;
+            std::string parentFrame;
         };
 
         std::vector<Frame> m_frames;
         irr::scene::ISceneManager* m_smgr;
+        std::shared_ptr<std::vector<ModelVisualization*>> m_models;
 
         void setFrameTransform(size_t index, const Transform& transformation);
 
@@ -37,7 +35,7 @@ namespace iDynTree
 
         ~FrameVisualization();
 
-        void init(irr::scene::ISceneManager* smgr);
+        void init(irr::scene::ISceneManager* smgr, std::shared_ptr<std::vector<ModelVisualization*>> models);
 
         void close();
 
@@ -55,6 +53,10 @@ namespace iDynTree
 
         virtual bool updateFrame(size_t frameIndex, const Transform& transformation) final;
 
+        virtual std::pair<std::string, std::string> getFrameParent(size_t frameIndex) const final;
+
+        virtual bool setFrameParent(size_t frameIndex, const std::string& modelName, const std::string& frameName) final;
+
         virtual ILabel* getFrameLabel(size_t frameIndex) final;
 
     };
