@@ -1,21 +1,14 @@
-/*
- * Copyright (C) 2016 Fondazione Istituto Italiano di Tecnologia
- *
- * Licensed under either the GNU Lesser General Public License v3.0 :
- * https://www.gnu.org/licenses/lgpl-3.0.html
- * or the GNU Lesser General Public License v2.1 :
- * https://www.gnu.org/licenses/old-licenses/lgpl-2.1.html
- * at your option.
- */
+// SPDX-FileCopyrightText: Fondazione Istituto Italiano di Tecnologia (IIT)
+// SPDX-License-Identifier: BSD-3-Clause
 
 #include "ModelVisualization.h"
 #include "JetsVisualization.h"
 #include "IrrlichtUtils.h"
 #include "Label.h"
 
-#include <iDynTree/Model/ForwardKinematics.h>
-#include <iDynTree/Model/Model.h>
-#include <iDynTree/Model/Traversal.h>
+#include <iDynTree/ForwardKinematics.h>
+#include <iDynTree/Model.h>
+#include <iDynTree/Traversal.h>
 
 namespace iDynTree
 {
@@ -174,6 +167,68 @@ ModelVisualization& ModelVisualization::operator=(const ModelVisualization& /*ot
     return *this;
 }
 
+bool ModelVisualization::changeVisualsColor(const LinkIndex& linkIndex, const ColorViz& color, const std::string& name)
+{
+    irr::video::SColor col = idyntree2irrlicht(color).toSColor();
+    bool changed = false;
+
+    for (size_t geom = 0; geom < pimpl->geomNodes[linkIndex].size(); geom++)
+    {
+        if (pimpl->geomNodes[linkIndex][geom] && (name.empty() ||
+            std::string(pimpl->geomNodes[linkIndex][geom]->getName()) == name))
+        {
+            irr::scene::ISceneNode* geomNode = pimpl->geomNodes[linkIndex][geom];
+
+            for (size_t mat = 0; mat < geomNode->getMaterialCount(); mat++)
+            {
+                irr::video::SMaterial geomMat = geomNode->getMaterial(mat);
+
+                // R
+                geomMat.AmbientColor.setRed(col.getRed());
+                geomMat.DiffuseColor.setRed(col.getRed());
+                geomMat.SpecularColor.setRed(col.getRed());
+                geomMat.EmissiveColor.setRed(col.getRed());
+
+                // G
+                geomMat.AmbientColor.setGreen(col.getGreen());
+                geomMat.DiffuseColor.setGreen(col.getGreen());
+                geomMat.SpecularColor.setGreen(col.getGreen());
+                geomMat.EmissiveColor.setGreen(col.getGreen());
+
+                // B
+                geomMat.AmbientColor.setBlue(col.getBlue());
+                geomMat.DiffuseColor.setBlue(col.getBlue());
+                geomMat.SpecularColor.setBlue(col.getBlue());
+                geomMat.EmissiveColor.setBlue(col.getBlue());
+
+                geomMat.AmbientColor.setAlpha(col.getAlpha());
+                geomMat.DiffuseColor.setAlpha(col.getAlpha());
+                geomMat.SpecularColor.setAlpha(col.getAlpha());
+                geomMat.EmissiveColor.setAlpha(col.getAlpha());
+
+                if (color.a < 1.0)
+                {
+                    geomMat.MaterialType = irr::video::EMT_TRANSPARENT_VERTEX_ALPHA;
+                }
+                else
+                {
+                    geomMat.MaterialType = irr::video::EMT_SOLID;
+                }
+
+
+                geomNode->getMaterial(mat) = geomMat;
+            }
+            geomNode->setMaterialFlag(irr::video::EMF_BACK_FACE_CULLING, false);
+            geomNode->setMaterialFlag(irr::video::EMF_NORMALIZE_NORMALS, true);
+            geomNode->setMaterialFlag(irr::video::EMF_COLOR_MATERIAL, false);
+            geomNode->setMaterialFlag(irr::video::EMF_BLEND_OPERATION, true);
+
+            changed = true;
+        }
+    }
+    return changed;
+}
+
 bool ModelVisualization::init(const Model& model,
                               const std::string instanceName,
                               irr::scene::ISceneManager * sceneManager)
@@ -345,38 +400,22 @@ bool ModelVisualization::setLinkColor(const LinkIndex& linkIndex, const ColorViz
         return false;
     }
 
-    irr::video::SColor col = idyntree2irrlicht(linkColor).toSColor();
-    for(size_t geom=0; geom < pimpl->geomNodes[linkIndex].size(); geom++)
+    changeVisualsColor(linkIndex, linkColor);
+    return true;
+}
+
+bool ModelVisualization::setVisualColor(const LinkIndex& linkIndex, const std::string& visualName, const ColorViz& visualColor)
+{
+    if (linkIndex < 0 || linkIndex >= pimpl->geomNodes.size())
     {
-        if( pimpl->geomNodes[linkIndex][geom] )
-        {
-            irr::scene::ISceneNode * geomNode = pimpl->geomNodes[linkIndex][geom];
+        reportError("ModelVisualization", "setVisualColor", "invalid link index");
+        return false;
+    }
 
-            for( size_t mat = 0; mat < geomNode->getMaterialCount(); mat++)
-            {
-                irr::video::SMaterial geomMat = geomNode->getMaterial(mat);
-
-                // R
-                geomMat.AmbientColor.setRed(col.getRed());
-                geomMat.DiffuseColor.setRed(col.getRed());
-                geomMat.SpecularColor.setRed(col.getRed());
-                geomMat.EmissiveColor.setRed(col.getRed());
-
-                // G
-                geomMat.AmbientColor.setGreen(col.getGreen());
-                geomMat.DiffuseColor.setGreen(col.getGreen());
-                geomMat.SpecularColor.setGreen(col.getGreen());
-                geomMat.EmissiveColor.setGreen(col.getGreen());
-
-                // B
-                geomMat.AmbientColor.setBlue(col.getBlue());
-                geomMat.DiffuseColor.setBlue(col.getBlue());
-                geomMat.SpecularColor.setBlue(col.getBlue());
-                geomMat.EmissiveColor.setBlue(col.getBlue());
-
-                geomNode->getMaterial(mat) = geomMat;
-            }
-        }
+    if (!changeVisualsColor(linkIndex, visualColor, visualName))
+    {
+        reportError("ModelVisualization", "setVisualColor", "Visual name not found");
+        return false;
     }
     return true;
 }
@@ -418,8 +457,14 @@ bool ModelVisualization::resetLinkColor(const LinkIndex& linkIndex)
                 geomMat.SpecularColor.setBlue(materialCache[mat].SpecularColor.getBlue());
                 geomMat.EmissiveColor.setBlue(materialCache[mat].EmissiveColor.getBlue());
 
+                geomMat.MaterialType = irr::video::EMT_SOLID;
+
                 geomNode->getMaterial(mat) = geomMat;
             }
+            geomNode->setMaterialFlag(irr::video::EMF_BACK_FACE_CULLING, false);
+            geomNode->setMaterialFlag(irr::video::EMF_NORMALIZE_NORMALS, true);
+            geomNode->setMaterialFlag(irr::video::EMF_COLOR_MATERIAL, true);
+            geomNode->setMaterialFlag(irr::video::EMF_BLEND_OPERATION, false);
         }
     }
    return true;
@@ -480,6 +525,18 @@ void ModelVisualization::close()
 
 }
 
+irr::scene::ISceneNode* ModelVisualization::getFrameSceneNode(const std::string& frameName)
+{
+    size_t frameIndex = pimpl->m_model.getFrameIndex(frameName);
+    if (frameIndex == FRAME_INVALID_INDEX)
+    {
+        std::string errorMsg = "Frame " + frameName + " not found";
+        reportError("ModelVisualization","getFrameSceneNode", errorMsg.c_str());
+        return nullptr;
+    }
+    return pimpl->frameNodes[frameIndex];
+}
+
 std::vector<std::string> ModelVisualization::getFeatures()
 {
     std::vector<std::string> ret;
@@ -489,6 +546,61 @@ std::vector<std::string> ModelVisualization::getFeatures()
     return ret;
 }
 
+void ModelVisualization::setModelTransparency(const double transparency)
+{
+    for (size_t linkIdx = 0; linkIdx < pimpl->geomNodes.size(); linkIdx++)
+    {
+        setLinkTransparency(linkIdx, transparency);
+    }
+}
+
+bool ModelVisualization::setLinkTransparency(const LinkIndex& linkIndex, const double transparency)
+{
+    if (linkIndex < 0 || linkIndex >= pimpl->geomNodes.size())
+    {
+        reportError("ModelVisualization", "setLinkTransparency", "invalid link index");
+        return false;
+    }
+    irr::u32 alphaValue = static_cast<irr::u32>(255.0 * transparency);
+
+
+    for (size_t geom = 0; geom < pimpl->geomNodes[linkIndex].size(); geom++)
+    {
+        if (pimpl->geomNodes[linkIndex][geom])
+        {
+            irr::scene::ISceneNode* geomNode = pimpl->geomNodes[linkIndex][geom];
+
+            for (size_t mat = 0; mat < geomNode->getMaterialCount(); mat++)
+            {
+                irr::video::SMaterial geomMat = geomNode->getMaterial(mat);
+
+                geomMat.AmbientColor.setAlpha(alphaValue);
+                geomMat.DiffuseColor.setAlpha(alphaValue);
+                geomMat.SpecularColor.setAlpha(alphaValue);
+                geomMat.EmissiveColor.setAlpha(alphaValue);
+
+                if (transparency < 1.0)
+                {
+                    geomMat.MaterialType = irr::video::EMT_TRANSPARENT_VERTEX_ALPHA;
+                }
+                else
+                {
+                    geomMat.MaterialType = irr::video::EMT_SOLID;
+                }
+
+
+                geomNode->getMaterial(mat) = geomMat;
+            }
+            geomNode->setMaterialFlag(irr::video::EMF_BACK_FACE_CULLING, false);
+            geomNode->setMaterialFlag(irr::video::EMF_NORMALIZE_NORMALS, true);
+            geomNode->setMaterialFlag(irr::video::EMF_COLOR_MATERIAL, false); //Do not use vertex color
+            geomNode->setMaterialFlag(irr::video::EMF_BLEND_OPERATION, true); //Blend colors to have the transparency effect
+        }
+    }
+
+    return true;
+}
+
 bool ModelVisualization::setFeatureVisibility(const std::string& elementKey, bool isVisible)
 {
     bool retValue = false;
