@@ -1,15 +1,8 @@
-/*
- * Copyright (C) 2016 Fondazione Istituto Italiano di Tecnologia
- *
- * Licensed under either the GNU Lesser General Public License v3.0 :
- * https://www.gnu.org/licenses/lgpl-3.0.html
- * or the GNU Lesser General Public License v2.1 :
- * https://www.gnu.org/licenses/old-licenses/lgpl-2.1.html
- * at your option.
- */
+// SPDX-FileCopyrightText: Fondazione Istituto Italiano di Tecnologia (IIT)
+// SPDX-License-Identifier: BSD-3-Clause
 
-#include <iDynTree/Core/Utils.h>
-#include <iDynTree/Model/JointState.h>
+#include <iDynTree/Utils.h>
+#include <iDynTree/JointState.h>
 #include <iDynTree/Visualizer.h>
 
 #ifdef IDYNTREE_USES_IRRLICHT
@@ -20,15 +13,50 @@
 #include "ModelVisualization.h"
 #include "VectorsVisualization.h"
 #include "FrameVisualization.h"
+#include "ShapesVisualization.h"
 #include "TexturesHandler.h"
 #include "CameraAnimator.h"
 #include "Label.h"
+
+#if defined(_WIN32)
+ #define GLFW_EXPOSE_NATIVE_WIN32
+ #define GLFW_EXPOSE_NATIVE_WGL
+#elif defined(__APPLE__)
+ #define GLFW_EXPOSE_NATIVE_COCOA
+ #define GLFW_EXPOSE_NATIVE_NSGL
+#elif defined(__linux__)
+ #define GLFW_EXPOSE_NATIVE_X11
+ #if defined(IDYNTREE_GLFW_TRY_WAYLAND_FIRST)
+   #define GLFW_EXPOSE_NATIVE_WAYLAND
+ #endif
+ #define GLFW_EXPOSE_NATIVE_GLX
+#endif
+
+#include <GLFW/glfw3.h>
+#include <GLFW/glfw3native.h>
+
+#if defined(_WIN32) && defined(_IRR_COMPILE_WITH_SDL_DEVICE_)
+// Required by SetEnvironmentVariableA, _putenv is not unsetting
+// correctly the variables
+#define NOMINMAX
+#define WIN32_LEAN_AND_MEAN
+#include <windows.h>
+#endif
+
+#if defined(_IRR_COMPILE_WITH_SDL_DEVICE_) || defined(_WIN32) ||  defined(__APPLE__)
+#if (defined(_WIN32) ||  defined(__APPLE__)) && !defined(_IRR_COMPILE_WITH_SDL_DEVICE_)
+#error "On Windows and MacOS it is necessary to use Irrlicht with SDL"
+#endif
+#define IDYNTREE_USE_GLFW_WINDOW
+#endif
+
 #endif
 
 #include "DummyImplementations.h"
 
 #include <unordered_map>
 #include <cassert>
+#include <memory>
 
 namespace iDynTree
 {
@@ -54,6 +82,10 @@ IFrameVisualization::~IFrameVisualization()
 {
 }
 
+IShapeVisualization::~IShapeVisualization()
+{
+}
+
 IModelVisualization::~IModelVisualization()
 {
 }
@@ -91,6 +123,16 @@ ColorViz::ColorViz(const Vector4& rgba): r(rgba(0)), g(rgba(1)), b(rgba(2)), a(r
 
 }
 
+Vector4 ColorViz::toVector4() const
+{
+    Vector4 ret;
+    ret(0) = r;
+    ret(1) = g;
+    ret(2) = b;
+    ret(3) = a;
+    return ret;
+}
+
 struct Visualizer::VisualizerPimpl
 {
     /**
@@ -109,10 +151,28 @@ struct Visualizer::VisualizerPimpl
     int lastFPS;
 
 #ifdef IDYNTREE_USES_IRRLICHT
+
+#ifdef IDYNTREE_USE_GLFW_WINDOW
+    /**
+     * Custom window object
+     */
+    GLFWwindow* m_window{nullptr};
+
+    static unsigned int m_glfwInstances;
+
+#if defined(_WIN32)
+    HWND m_windowId;
+#elif defined(__APPLE__)
+    id m_windowId;
+#elif defined(__linux__)
+    void* m_windowId; // Pointer to either wl_surface* or X11 Window
+#endif
+#endif
+
     /**
      * Collection of model visualization.
      */
-    std::vector<ModelVisualization*> m_modelViz;
+    std::shared_ptr<std::vector<ModelVisualization*>> m_modelViz;
 
     /**
      * Irrlicht device used by the visualizer.
@@ -154,6 +214,11 @@ struct Visualizer::VisualizerPimpl
      */
     FrameVisualization m_frames;
 
+    /**
+     * Shapes visualization
+     */
+    ShapeVisualization m_shapes;
+
     /**
      * Textures handling
      */
@@ -205,12 +270,154 @@ struct Visualizer::VisualizerPimpl
         m_palette["meshcat"].zAxis = irr::video::SColor(alphaLev,66,133,244);
         m_palette["meshcat"].vector = irr::video::SColor(255,253,98,2);
     }
+
+#ifdef IDYNTREE_USE_GLFW_WINDOW
+    void cursorPositionCallback(GLFWwindow* window, double xpos, double ypos)
+    {
+        if (window != m_window)
+        {
+            return;
+        }
+
+        if (!m_isInitialized)
+        {
+            return;
+        }
+
+        GLint ww, wh;
+        glfwGetWindowSize(window, &ww, &wh);
+
+        irr::SEvent::SMouseInput mouseEvent;
+
+        mouseEvent.Event = irr::EMOUSE_INPUT_EVENT::EMIE_MOUSE_MOVED;
+        mouseEvent.X = xpos;
+        mouseEvent.Y = ypos;
+
+        irr::SEvent event;
+        event.EventType = irr::EEVENT_TYPE::EET_MOUSE_INPUT_EVENT;
+        event.MouseInput = mouseEvent;
+
+        m_irrDevice->postEventFromUser(event);
+    }
+
+    void mouseButtonCallback(GLFWwindow* window, int button, int action, int)
+    {
+        if (window != m_window)
+        {
+            return;
+        }
+
+        if (!m_isInitialized)
+        {
+            return;
+        }
+
+        irr::SEvent::SMouseInput mouseEvent;
+
+        if (button == GLFW_MOUSE_BUTTON_RIGHT)
+        {
+            if (action == GLFW_PRESS)
+            {
+                mouseEvent.Event = irr::EMOUSE_INPUT_EVENT::EMIE_RMOUSE_PRESSED_DOWN;
+            }
+            else if (action == GLFW_RELEASE)
+            {
+                mouseEvent.Event = irr::EMOUSE_INPUT_EVENT::EMIE_RMOUSE_LEFT_UP;
+            }
+            else
+            {
+                return;
+            }
+        }
+        else if (button == GLFW_MOUSE_BUTTON_LEFT)
+        {
+            if (action == GLFW_PRESS)
+            {
+                mouseEvent.Event = irr::EMOUSE_INPUT_EVENT::EMIE_LMOUSE_PRESSED_DOWN;
+            }
+            else if (action == GLFW_RELEASE)
+            {
+                mouseEvent.Event = irr::EMOUSE_INPUT_EVENT::EMIE_LMOUSE_LEFT_UP;
+            }
+            else
+            {
+                return;
+            }
+        }
+        else if (button == GLFW_MOUSE_BUTTON_MIDDLE)
+        {
+            if (action == GLFW_PRESS)
+            {
+                mouseEvent.Event = irr::EMOUSE_INPUT_EVENT::EMIE_MMOUSE_PRESSED_DOWN;
+            }
+            else if (action == GLFW_RELEASE)
+            {
+                mouseEvent.Event = irr::EMOUSE_INPUT_EVENT::EMIE_MMOUSE_LEFT_UP;
+            }
+            else
+            {
+                return;
+            }
+        }
+        else
+        {
+            return;
+        }
+
+        irr::SEvent event;
+        event.EventType = irr::EEVENT_TYPE::EET_MOUSE_INPUT_EVENT;
+        event.MouseInput = mouseEvent;
+
+        m_irrDevice->postEventFromUser(event);
+    }
+
+    void scrollCallback(GLFWwindow* window, double, double yoffset)
+    {
+        if (window != m_window)
+        {
+            return;
+        }
+
+        if (!m_isInitialized)
+        {
+            return;
+        }
+
+        irr::SEvent::SMouseInput mouseEvent;
+
+        mouseEvent.Event = irr::EMOUSE_INPUT_EVENT::EMIE_MOUSE_WHEEL;
+        mouseEvent.Wheel = yoffset;
+
+        irr::SEvent event;
+        event.EventType = irr::EEVENT_TYPE::EET_MOUSE_INPUT_EVENT;
+        event.MouseInput = mouseEvent;
+
+        m_irrDevice->postEventFromUser(event);
+    }
+
+    static void cursor_position_callback(GLFWwindow* window, double xpos, double ypos)
+    {
+        static_cast<Visualizer::VisualizerPimpl*>(glfwGetWindowUserPointer(window))->cursorPositionCallback(window, xpos, ypos);
+    }
+
+    static void mouse_button_callback(GLFWwindow* window, int button, int action, int mods)
+    {
+        static_cast<Visualizer::VisualizerPimpl*>(glfwGetWindowUserPointer(window))->mouseButtonCallback(window, button, action, mods);
+    }
+
+    static void scroll_callback(GLFWwindow* window, double xoffset, double yoffset)
+    {
+        static_cast<Visualizer::VisualizerPimpl*>(glfwGetWindowUserPointer(window))->scrollCallback(window, xoffset, yoffset);
+    }
+#endif
+
 #else
     DummyCamera m_camera;
     DummyEnvironment m_environment;
     DummyVectorsVisualization m_invalidVectors;
     DummyFrameVisualization m_invalidFrames;
     DummyTexturesHandler m_invalidTextures;
+    DummyShapeVisualization m_invalidShapes;
     DummyLabel m_invalidLabel;
 #endif
 
@@ -220,7 +427,8 @@ struct Visualizer::VisualizerPimpl
         lastFPS = -1;
 
 #ifdef IDYNTREE_USES_IRRLICHT
-        m_modelViz.resize(0);
+        m_modelViz = std::make_shared<std::vector<ModelVisualization*>>();
+        m_modelViz->resize(0);
         m_irrDevice  = 0;
         m_irrSmgr    = 0;
         m_irrDriver  = 0;
@@ -228,6 +436,11 @@ struct Visualizer::VisualizerPimpl
     }
 };
 
+#ifdef IDYNTREE_USE_GLFW_WINDOW
+
+unsigned int Visualizer::VisualizerPimpl::m_glfwInstances = 0;
+
+#endif
 
 Visualizer::Visualizer(const Visualizer& /*other*/)
 {
@@ -267,12 +480,61 @@ bool Visualizer::init(const VisualizerOptions &visualizerOptions)
 
     irr::SIrrlichtCreationParameters irrDevParams;
 
-// If we are on Windows and the SDL backend of Irrlicht is available,
-// let's use it to avoid spurios WM_QUIT signal being raised in the
-// close() method, see https://github.com/robotology/idyntree/issues/975
-#if defined(_WIN32) && defined(_IRR_COMPILE_WITH_SDL_DEVICE_)
+#ifdef IDYNTREE_USE_GLFW_WINDOW
+    if (pimpl->m_glfwInstances == 0)
+    {
+        if (!glfwInit()) {
+            reportError("Visualizer", "init", "Unable to initialize GLFW");
+            return false;
+        }
+
+        glfwWindowHint(GLFW_SAMPLES, 4); //Antialiasing
+    }
+    pimpl->m_glfwInstances++;
+
+    pimpl->m_window = glfwCreateWindow(visualizerOptions.winWidth, visualizerOptions.winHeight, "iDynTree Visualizer", nullptr, nullptr);
+    if (!pimpl->m_window) {
+        reportError("Visualizer","init","Could not create window");
+        return false;
+    }
+
+    glfwMakeContextCurrent(pimpl->m_window);
+    glfwSwapInterval(1);
+
+#if defined(_WIN32)
+    pimpl->m_windowId = glfwGetWin32Window(pimpl->m_window);
+    irrDevParams.WindowId = (void*)(pimpl->m_windowId);
+#elif defined(__APPLE__)
+    pimpl->m_windowId = glfwGetCocoaWindow(pimpl->m_window);
+    irrDevParams.WindowId = (void*)(pimpl->m_windowId);
+#elif defined(__linux__)
+
+    void* nativeWindow = nullptr;
+
+    #ifdef IDYNTREE_GLFW_TRY_WAYLAND_FIRST
+        // Try Wayland first
+        struct wl_surface* waylandWindow = glfwGetWaylandWindow(pimpl->m_window);
+    #else
+        void* waylandWindow = nullptr;
+    #endif
+
+    if (waylandWindow)
+    {
+        nativeWindow = static_cast<void*>(waylandWindow);
+    }
+    else
+    {
+        // Fallback to X11
+        Window x11Window = glfwGetX11Window(pimpl->m_window);
+        if (x11Window)
+            nativeWindow = static_cast<void*>(reinterpret_cast<void*>(x11Window));
+    }
+    irrDevParams.WindowId = nativeWindow;
+#endif
+
     irrDevParams.DeviceType = irr::EIDT_SDL;
 #endif
+
     irrDevParams.DriverType = irr::video::EDT_OPENGL;
     irrDevParams.WindowSize = irr::core::dimension2d<irr::u32>(visualizerOptions.winWidth, visualizerOptions.winHeight);
     irrDevParams.WithAlphaChannel = true;
@@ -285,8 +547,26 @@ bool Visualizer::init(const VisualizerOptions &visualizerOptions)
     }
 
     pimpl->m_irrDevice = 0;
+
+// The Irrlicht SDL device overwrites the value of the SDL_VIDEODRIVER
+// environment variable, and this prevents the driver to work correctly.
+// For this reason, we save the value before the irr::createDeviceEx call,
+// and we restore it (or we unset it) after call
+// Workaround for https://github.com/robotology/idyntree/issues/986
+#if defined(_WIN32) && defined(_IRR_COMPILE_WITH_SDL_DEVICE_)
+    const char * SDL_VIDEODRIVER_value = NULL;
+    if (irrDevParams.DeviceType == irr::EIDT_SDL) {
+        SDL_VIDEODRIVER_value = std::getenv("SDL_VIDEODRIVER");
+    }
+#endif
+
     pimpl->m_irrDevice = irr::createDeviceEx(irrDevParams);
 
+#if defined(_WIN32) && defined(_IRR_COMPILE_WITH_SDL_DEVICE_)
+    if (irrDevParams.DeviceType == irr::EIDT_SDL) {
+        SetEnvironmentVariableA("SDL_VIDEODRIVER", SDL_VIDEODRIVER_value);
+    }
+#endif
 
     if (pimpl->m_irrDevice == 0)
     {
@@ -319,15 +599,23 @@ bool Visualizer::init(const VisualizerOptions &visualizerOptions)
     pimpl->m_environment.init(pimpl->m_irrSmgr, pimpl->rootFrameArrowsDimension);
 
     pimpl->m_camera.setIrrlichtCamera(addVizCamera(pimpl->m_irrSmgr));
-    pimpl->m_camera.setCameraAnimator(new CameraAnimator(pimpl->m_irrDevice->getCursorControl(),
-                                                         addFrameAxes(pimpl->m_irrSmgr, 0, 0.1)));
+    pimpl->m_camera.setCameraAnimator(new CameraAnimator(addFrameAxes(pimpl->m_irrSmgr, 0, 0.1), visualizerOptions.winWidth, visualizerOptions.winHeight));
 
     pimpl->m_vectors.init(pimpl->m_irrSmgr);
 
-    pimpl->m_frames.init(pimpl->m_irrSmgr);
+    pimpl->m_frames.init(pimpl->m_irrSmgr, pimpl->m_modelViz);
+
+    pimpl->m_shapes.init(pimpl->m_irrSmgr, pimpl->m_modelViz);
 
     pimpl->m_textures.init(pimpl->m_irrDriver, pimpl->m_irrSmgr);
 
+#ifdef IDYNTREE_USE_GLFW_WINDOW
+    glfwSetWindowUserPointer(pimpl->m_window, pimpl);
+    glfwSetCursorPosCallback(pimpl->m_window, VisualizerPimpl::cursor_position_callback);
+    glfwSetMouseButtonCallback(pimpl->m_window, VisualizerPimpl::mouse_button_callback);
+    glfwSetScrollCallback(pimpl->m_window, VisualizerPimpl::scroll_callback);
+#endif
+
     pimpl->m_isInitialized = true;
     pimpl->lastFPS         = -1;
 
@@ -342,7 +630,7 @@ bool Visualizer::init(const VisualizerOptions &visualizerOptions)
 size_t Visualizer::getNrOfVisualizedModels()
 {
 #ifdef IDYNTREE_USES_IRRLICHT
-    return pimpl->m_modelViz.size();
+    return pimpl->m_modelViz->size();
 #else
     return 0;
 #endif
@@ -357,7 +645,7 @@ std::string Visualizer::getModelInstanceName(size_t modelInstanceIndex)
     }
 
 #ifdef IDYNTREE_USES_IRRLICHT
-    return pimpl->m_modelViz[modelInstanceIndex]->getInstanceName();
+    return pimpl->m_modelViz->at(modelInstanceIndex)->getInstanceName();
 #else
     return "";
 #endif
@@ -369,7 +657,7 @@ int Visualizer::getModelInstanceIndex(const std::string instanceName)
 #ifdef IDYNTREE_USES_IRRLICHT
     for(size_t mdlInst=0; mdlInst < getNrOfVisualizedModels(); mdlInst++)
     {
-        if( pimpl->m_modelViz[mdlInst]->getInstanceName() == instanceName )
+        if( pimpl->m_modelViz->at(mdlInst)->getInstanceName() == instanceName )
         {
             return static_cast<int>(mdlInst);
         }
@@ -405,7 +693,7 @@ bool Visualizer::addModel(const Model& model, const std::string& instanceName)
         return false;
     }
 
-    this->pimpl->m_modelViz.push_back(newModelViz);
+    this->pimpl->m_modelViz->push_back(newModelViz);
 
     return true;
 #else
@@ -435,13 +723,19 @@ void Visualizer::draw()
             return;
         }
 
+#ifdef IDYNTREE_USE_GLFW_WINDOW
+        glfwMakeContextCurrent(pimpl->m_window);
+#endif
+
         pimpl->m_irrDriver->beginScene(true,true, pimpl->m_environment.m_backgroundColor.toSColor(), pimpl->m_irrVideoData);
 
         pimpl->m_irrDriver->setViewPort(irr::core::rect<irr::s32>(0, 0, winWidth, winHeight));
 
+        pimpl->m_irrDriver->OnResize(irr::core::dimension2d<irr::u32>(winWidth, winHeight));
+
         pimpl->m_textures.draw(pimpl->m_environment, pimpl->m_camera, true);
 
-        pimpl->m_camera.setAspectRatio(winWidth/ (float)winHeight);
+        pimpl->m_camera.setWindowDimensions(winWidth, winHeight);
 
         pimpl->m_irrSmgr->drawAll();
     }
@@ -449,6 +743,12 @@ void Visualizer::draw()
     pimpl->m_irrDriver->endScene();
     pimpl->m_subDrawStarted = false;
 
+#ifdef IDYNTREE_USE_GLFW_WINDOW
+    glfwSwapBuffers(pimpl->m_window);
+
+    glfwPollEvents();
+#endif
+
     int fps = pimpl->m_irrDriver->getFPS();
 
     if (pimpl->lastFPS != fps)
@@ -458,8 +758,12 @@ void Visualizer::draw()
         str += "] FPS:";
         str += fps;
         str += " ";
+        irr::core::stringc strc(str);
 
         pimpl->m_irrDevice->setWindowCaption(str.c_str());
+#ifdef IDYNTREE_USE_GLFW_WINDOW
+        glfwSetWindowTitle(pimpl->m_window, strc.c_str());
+#endif
         pimpl->lastFPS = fps;
     }
 
@@ -497,6 +801,9 @@ void Visualizer::subDraw(int xOffsetFromTopLeft, int yOffsetFromTopLeft, int sub
     bool clearTextureBuffers = false;
     if (!pimpl->m_subDrawStarted)
     {
+#ifdef IDYNTREE_USE_GLFW_WINDOW
+        glfwMakeContextCurrent(pimpl->m_window);
+#endif
         pimpl->m_irrDriver->beginScene(true,true, pimpl->m_environment.m_backgroundColor.toSColor(), pimpl->m_irrVideoData);
         pimpl->m_subDrawStarted = true;
         clearTextureBuffers = true;
@@ -506,7 +813,10 @@ void Visualizer::subDraw(int xOffsetFromTopLeft, int yOffsetFromTopLeft, int sub
 
     pimpl->m_camera.setAspectRatio(subImageWidth/ (float)subImageHeight);
 
-    pimpl->m_irrDriver->setViewPort(irr::core::rect<irr::s32>(0, 0, width(), height())); //workaround for http://irrlicht.sourceforge.net/forum/viewtopic.php?f=7&t=47004
+    int winWidth = width();
+    int winHeight = height();
+    pimpl->m_irrDriver->OnResize(irr::core::dimension2d<irr::u32>(winWidth, winHeight));
+    pimpl->m_irrDriver->setViewPort(irr::core::rect<irr::s32>(0, 0, winWidth, winHeight)); //workaround for http://irrlicht.sourceforge.net/forum/viewtopic.php?f=7&t=47004
     pimpl->m_irrDriver->setViewPort(irr::core::rect<irr::s32>(xOffsetFromTopLeft, yOffsetFromTopLeft,
                                                               xOffsetFromTopLeft + subImageWidth, yOffsetFromTopLeft + subImageHeight));
 
@@ -570,7 +880,7 @@ IModelVisualization& Visualizer::modelViz(const std::string& instanceName)
     }
 
 #ifdef IDYNTREE_USES_IRRLICHT
-    return *(this->pimpl->m_modelViz[idx]);
+    return *(this->pimpl->m_modelViz->at(idx));
 #else
     return this->pimpl->m_invalidModelViz;
 #endif
@@ -579,7 +889,7 @@ IModelVisualization& Visualizer::modelViz(const std::string& instanceName)
 IModelVisualization& Visualizer::modelViz(size_t modelIdx)
 {
 #ifdef IDYNTREE_USES_IRRLICHT
-    return *(this->pimpl->m_modelViz[modelIdx]);
+    return *(this->pimpl->m_modelViz->at(modelIdx));
 #else
     return this->pimpl->m_invalidModelViz;
 #endif
@@ -635,6 +945,19 @@ ITexturesHandler &Visualizer::textures()
 #endif
 }
 
+IShapeVisualization& Visualizer::shapes()
+{
+#ifdef IDYNTREE_USES_IRRLICHT
+    if (!this->pimpl->m_isInitialized)
+    {
+        init();
+    }
+    return this->pimpl->m_shapes;
+#else
+    return this->pimpl->m_invalidShapes;
+#endif
+}
+
 ILabel &Visualizer::getLabel(const std::string &labelName)
 {
 #ifdef IDYNTREE_USES_IRRLICHT
@@ -661,9 +984,15 @@ int Visualizer::width() const
         reportError("Visualizer","width","Visualizer not initialized.");
         return 0;
     }
+#ifdef IDYNTREE_USE_GLFW_WINDOW
+    GLint ww, wh;
+    glfwGetWindowSize(pimpl->m_window, &ww, &wh);
 
+    return ww;
+#else
     auto winDimensions = pimpl->m_irrDriver->getScreenSize();
     return winDimensions.Width;
+#endif
 #else
     return 0;
 #endif
@@ -678,8 +1007,15 @@ int Visualizer::height() const
         return 0;
     }
 
+#ifdef IDYNTREE_USE_GLFW_WINDOW
+    GLint ww, wh;
+    glfwGetWindowSize(pimpl->m_window, &ww, &wh);
+
+    return wh;
+#else
     auto winDimensions = pimpl->m_irrDriver->getScreenSize();
     return winDimensions.Height;
+#endif
 #else
     return 0;
 #endif
@@ -693,8 +1029,13 @@ bool Visualizer::run()
         reportError("Visualizer","run","Impossible to run not initialized visualizer");
         return false;
     }
+    bool shouldClose = false;
 
-    return pimpl->m_irrDevice->run();
+#ifdef IDYNTREE_USE_GLFW_WINDOW
+    shouldClose = glfwWindowShouldClose(pimpl->m_window);
+#endif
+
+    return pimpl->m_irrDevice->run() && !shouldClose;
 #else
     reportError("Visualizer","run","Impossible to use iDynTree::Visualizer, as iDynTree has been compiled without Irrlicht.");
     return false;
@@ -708,6 +1049,9 @@ void Visualizer::close()
     {
         return;
     }
+#ifdef IDYNTREE_USE_GLFW_WINDOW
+    glfwMakeContextCurrent(pimpl->m_window);
+#endif
 
     pimpl->m_vectors.close();
     pimpl->m_frames.close();
@@ -718,16 +1062,32 @@ void Visualizer::close()
     pimpl->m_irrDevice = nullptr;
     pimpl->m_isInitialized = false;
 
-    for(size_t mdl=0; mdl < pimpl->m_modelViz.size(); mdl++)
+    for(size_t mdl=0; mdl < pimpl->m_modelViz->size(); mdl++)
     {
-        if( pimpl->m_modelViz[mdl] )
+        if( pimpl->m_modelViz->at(mdl))
         {
-            delete pimpl->m_modelViz[mdl];
-            pimpl->m_modelViz[mdl] = nullptr;
+            delete pimpl->m_modelViz->at(mdl);
+            pimpl->m_modelViz->at(mdl) = nullptr;
         }
     }
 
-    pimpl->m_modelViz.resize(0);
+    pimpl->m_modelViz->resize(0);
+
+#ifdef IDYNTREE_USE_GLFW_WINDOW
+    if (pimpl->m_window)
+    {
+        glfwMakeContextCurrent(pimpl->m_window);
+        glfwDestroyWindow(pimpl->m_window);
+
+        pimpl->m_glfwInstances--;
+        if (pimpl->m_glfwInstances == 0)
+        {
+            glfwTerminate();
+        }
+
+        pimpl->m_window = nullptr;
+    }
+#endif
 
     return;
 #endif
